(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    274959,       5448]
NotebookOptionsPosition[    270103,       5288]
NotebookOutlinePosition[    270467,       5304]
CellTagsIndexPosition[    270424,       5301]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Van-der-Pol Oscillator", "Chapter",
 CellChangeTimes->{{3.7510414686725473`*^9, 3.7510414804850674`*^9}, {
  3.751048518504573*^9, 3.7510485214535766`*^9}}],

Cell[CellGroupData[{

Cell["Numeric example", "Subchapter",
 CellChangeTimes->{{3.751042126994077*^9, 3.7510421346763463`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"van", " ", "der", " ", "Pol", " ", "oscillator"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"LHS", ":=", 
   RowBox[{
    RowBox[{"m", " ", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "2"}], "}"}]}], "]"}]}], "-", 
    RowBox[{"\[Gamma]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], "\[CapitalLambda]"}], "-", 
       SuperscriptBox[
        RowBox[{"x", "[", "t", "]"}], "2"]}], ")"}], 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", "t"}], "]"}]}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"x", "[", "t", "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.751001672028022*^9, 3.7510017308528385`*^9}, 
   3.7510029833482227`*^9, {3.7510280971011224`*^9, 3.7510280976492076`*^9}, {
   3.7510416306241736`*^9, 3.7510416333629756`*^9}, {3.7510417506378202`*^9, 
   3.7510417510378294`*^9}, {3.751115825991867*^9, 3.7511158349084845`*^9}, {
   3.751117308550481*^9, 3.751117311902508*^9}, {3.751117688805976*^9, 
   3.7511176983032646`*^9}, {3.751117771258339*^9, 3.7511177951464777`*^9}, {
   3.7511178895349116`*^9, 3.75111799350047*^9}, {3.751118906386414*^9, 
   3.751118906478013*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"vals", ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"m", "\[Rule]", "1"}], ",", 
    RowBox[{"\[Gamma]", "\[Rule]", "4"}], ",", 
    RowBox[{"k", "\[Rule]", "1"}], ",", 
    RowBox[{"\[CapitalLambda]", "\[Rule]", "1"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x0", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", ":=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xsim", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"LHS", "\[Equal]", "0"}], "/.", "vals"}], ",", 
       RowBox[{
        RowBox[{"x", "[", "0", "]"}], "\[Equal]", "x0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"x", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], "/.", "xsim"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<x\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", 
              SuperscriptBox["\[CapitalLambda]", 
               RowBox[{"1", "/", "2"}]]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"tmax", ",", 
              SuperscriptBox["\[CapitalLambda]", 
               RowBox[{"1", "/", "2"}]]}], "}"}]}], "}"}], "/.", "vals"}], 
         "]"}]}], "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Mu]", "=", 
   RowBox[{"\[Gamma]", "/", 
    RowBox[{"(", 
     RowBox[{"8", "m"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x0", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"\[Mu]", " ", "t"}], "]"}]}], "/.", "vals"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{
        RowBox[{"10", "/", "\[Mu]"}], "/.", "vals"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "p2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.751041518399702*^9, 3.751041602802282*^9}, {
  3.7510416422695293`*^9, 3.75104170691206*^9}, {3.751041774632004*^9, 
  3.751041790684681*^9}, {3.7510423434431915`*^9, 3.7510423855240803`*^9}, {
  3.7511158422238455`*^9, 3.7511158482406206`*^9}, {3.751117052778956*^9, 
  3.7511170745507307`*^9}, {3.7511171555294127`*^9, 3.751117224944344*^9}, {
  3.7511173255965223`*^9, 3.7511176270078135`*^9}, {3.7511177075897455`*^9, 
  3.751117729493965*^9}, {3.7511177795485516`*^9, 3.7511177799595203`*^9}, {
  3.7511178124919243`*^9, 3.7511178328399982`*^9}, {3.751117998290409*^9, 
  3.751118050087783*^9}, {3.7511189164568872`*^9, 3.751118949596817*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwUl3k8ld8Tx2Xfk+wk+559387guiSkEpIKbYoK2ZKd0iIhSSpRFIlECOUI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       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwVlmc4Ffwbx42USB1bssc5OMY5Rulp/L6Umciq7KyopCihVEIZEWkQCUVp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       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    RGBColor[1, 0, 0], 
    LineBox[{{0, 1}, {100, 1}}]},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 100}, {-1.0043087754830438`, 1.0043097431051233`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.751041672696489*^9, 3.751041707481389*^9, 3.751041754225868*^9, 
   3.751041791670373*^9, {3.751042344028282*^9, 3.7510423861144285`*^9}, 
   3.751047619732955*^9, {3.7511158507273426`*^9, 3.751115854146813*^9}, 
   3.751117075151162*^9, {3.75111715636119*^9, 3.7511172263152556`*^9}, {
   3.7511173176566076`*^9, 3.751117379450202*^9}, {3.7511174462268443`*^9, 
   3.751117469834799*^9}, {3.751117499868037*^9, 3.7511176273394823`*^9}, {
   3.7511177005997486`*^9, 3.751117730212795*^9}, {3.7511177743293114`*^9, 
   3.7511177807118797`*^9}, {3.751117813292474*^9, 3.7511178333401628`*^9}, {
   3.7511178943250637`*^9, 3.7511180505350466`*^9}, 3.751118091377607*^9, {
   3.7511189106356916`*^9, 3.7511189507537184`*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlist", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "/.", "xsim"}], "//", "Evaluate"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "tmax", ",", "0.1"}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dxlist", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], "/.", "xsim"}], ",", "t"}], "]"}], "//",
        "Evaluate"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "tmax", ",", "0.1"}], "}"}]}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.751041847695326*^9, 3.7510418555438824`*^9}, {
  3.7510418939922953`*^9, 3.7510419086276865`*^9}, {3.751041957614102*^9, 
  3.7510420330883045`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotxdx", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"xlist", ",", "dxlist"}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x\>\"", ",", "\"\<dx/dt\>\""}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.751042059280138*^9, 3.7510421006556015`*^9}, {
  3.751044066367116*^9, 3.751044087243449*^9}, {3.751115858818682*^9, 
  3.7511158739608445`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwdmnk8VN//x21JUlKRJbQhylZaaHlLUpSyfERJVErWlBAtWihbJFKElEQL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      "]]}}, {}, {}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"dx/dt\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0043054588351719`, 
   1.004308365123464}, {-1.3392200225741655`, 1.3391446997856968`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7510420628667145`*^9, 3.751042101439844*^9}, {
   3.7510423488319273`*^9, 3.751042390052017*^9}, {3.751044074106422*^9, 
   3.751044088391532*^9}, 3.7510476222168202`*^9, 3.7510479328568864`*^9, {
   3.751115856779225*^9, 3.7511158743922777`*^9}, {3.7511173433172383`*^9, 
   3.751117381320972*^9}, 3.751117630341179*^9, {3.7511180365236177`*^9, 
   3.751118055854777*^9}, 3.751118093505246*^9, {3.7511189400135727`*^9, 
   3.7511189528063054`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mapping on Hopf oscillator", "Subchapter",
 CellChangeTimes->{{3.751042141740327*^9, 3.7510421503329196`*^9}}],

Cell[CellGroupData[{

Cell["Complex oscillator variable", "Subsection",
 CellChangeTimes->{{3.7510424926844482`*^9, 3.751042505358996*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"introduce", " ", "y"}], "=", 
   RowBox[{
    RowBox[{"x", "'"}], "[", "t", "]"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.751003141350003*^9, 3.7510031528707075`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"complex", " ", "oscillator", " ", 
    RowBox[{"variable", ":", " ", 
     RowBox[{
     "nonlinear", " ", "transformation", " ", "with", " ", "yet", " ", 
      "unknown", " ", "coefficients"}], ":", " ", 
     RowBox[{"simpler", " ", 
      RowBox[{"Ansatz", " ", "[", 
       RowBox[{"no", " ", "quadratic", " ", "terms"}], "]"}]}]}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Z", "=", 
    RowBox[{"x", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["I", "w0"]}], "+", 
        RowBox[{"I", " ", "d10im"}]}], " ", ")"}], "y"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"d33re", "+", 
        RowBox[{"I", " ", "d33im"}]}], ")"}], " ", 
      SuperscriptBox["x", "3"]}], " ", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"d32re", " ", "+", " ", 
        RowBox[{"I", " ", "d32im"}]}], ")"}], " ", 
      SuperscriptBox["x", "2"], "y"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"d31re", " ", "+", " ", 
        RowBox[{"I", " ", "d31im"}]}], ")"}], " ", "x", " ", 
      SuperscriptBox["y", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"d30re", "+", 
        RowBox[{"I", " ", "d30im"}]}], ")"}], " ", 
      SuperscriptBox["y", "3"]}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.751004204139959*^9, 3.751004211313554*^9}, {
   3.7510043757924523`*^9, 3.7510043850766134`*^9}, {3.7510056628515205`*^9, 
   3.751005699659149*^9}, {3.7510057520729623`*^9, 3.7510057709736795`*^9}, 
   3.7510058020134068`*^9, {3.7510058945875883`*^9, 3.751005895657106*^9}, {
   3.751005939173365*^9, 3.7510059398527284`*^9}, {3.7510281344533467`*^9, 
   3.7510281349377675`*^9}, {3.751042294560754*^9, 3.7510423067778673`*^9}, {
   3.7510466521610126`*^9, 3.7510468690432444`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"complex", " ", "conjugate"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Zbar", "=", 
    RowBox[{
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Conjugate", "[", "Z", "]"}], "]"}], "//", "Expand"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.7510057806328926`*^9, 3.7510057984948854`*^9}, {
  3.7510058975591726`*^9, 3.7510059450781155`*^9}, {3.751028137539581*^9, 
  3.751028139073413*^9}, {3.751042310968223*^9, 3.7510423168030095`*^9}, {
  3.7510468838993216`*^9, 3.751046935533106*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Back transformation", "Subsection",
 CellChangeTimes->{{3.7510425154159145`*^9, 3.751042526707777*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"back", " ", 
    RowBox[{"transformation", " ", ":", " ", "Ansatz"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"xBack", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Z", "+", "Zbar"}], ")"}], "/", "2"}], "+", 
      RowBox[{"e1", " ", 
       SuperscriptBox["Z", "3"]}], "+", 
      RowBox[{"e2", " ", 
       SuperscriptBox["Z", "2"], "Zbar"}], " ", "+", 
      RowBox[{"e3", " ", "Z", " ", 
       SuperscriptBox["Zbar", "2"]}], "+", 
      RowBox[{"e4", " ", 
       SuperscriptBox["Zbar", "3"]}]}], "//", "Simplify"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.75100580548506*^9, 3.7510058167567115`*^9}, {
  3.7510059617074933`*^9, 3.75100603931878*^9}, {3.7510062549997544`*^9, 
  3.751006267110505*^9}, {3.751006316493374*^9, 3.751006325285044*^9}, {
  3.7510298956583257`*^9, 3.7510299040791197`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"expand", " ", "to", " ", "third", " ", "order"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"xBack2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"xBack", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "\[Rule]", 
              RowBox[{"\[Epsilon]", " ", "x"}]}], ",", 
             RowBox[{"y", "\[Rule]", 
              RowBox[{"\[Epsilon]", " ", "y"}]}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]", ",", "0", ",", "3"}], "}"}]}], "]"}], "//", 
        "Normal"}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]", "\[Rule]", "1"}], "}"}]}], "//", "Expand"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.7510060406864786`*^9, 3.751006146665739*^9}, {
   3.7510061836038165`*^9, 3.751006185167321*^9}, 3.7510064649875207`*^9, {
   3.751029905195717*^9, 3.751029911793641*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "solve", " ", "for", " ", "unknown", " ", "coefficients", " ", "in", " ", 
    "back", " ", "transformation"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"esol", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"xBack2", ",", 
            SuperscriptBox["x", "3"]}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"xBack2", ",", 
            RowBox[{
             SuperscriptBox["x", "2"], "y"}]}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"xBack2", ",", 
            RowBox[{"x", " ", 
             SuperscriptBox["y", "2"]}]}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"xBack2", ",", 
            SuperscriptBox["y", "3"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"e1", ",", "e2", ",", "e3", ",", "e4"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.7510061985769277`*^9, 3.7510062492282963`*^9}, {
  3.751006334669422*^9, 3.7510063599923077`*^9}, {3.751029916006425*^9, 
  3.751029934772744*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "formal", " ", "representation", " ", "of", " ", "back", " ", 
    "transformation"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"xBack0", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Z0", "+", "Z0bar"}], ")"}], "/", "2"}], "+", 
       RowBox[{"e1", " ", 
        SuperscriptBox["Z0", "3"]}], "+", 
       RowBox[{"e2", " ", 
        SuperscriptBox["Z0", "2"], "Z0bar"}], " ", "+", 
       RowBox[{"e3", " ", "Z0", " ", 
        SuperscriptBox["Z0bar", "2"]}], "+", 
       RowBox[{"e4", " ", 
        SuperscriptBox["Z0bar", "3"]}]}], "/.", "esol"}], "//", 
     "Simplify"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.7510065362458086`*^9, 3.751006558742041*^9}, {
  3.751006683524419*^9, 3.751006684465089*^9}, {3.751029945513954*^9, 
  3.751029955373561*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Sanity", " ", "check"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xBack0", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Z0", "\[Rule]", "Z"}], ",", 
            RowBox[{"Z0bar", "\[Rule]", "Zbar"}]}], "}"}]}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "\[Rule]", 
           RowBox[{"\[Epsilon]", " ", "x"}]}], ",", 
          RowBox[{"y", "\[Rule]", 
           RowBox[{"\[Epsilon]", " ", "y"}]}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", "0", ",", "3"}], "}"}]}], "]"}], "//", 
     "Normal"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{"\[Epsilon]", "\[Rule]", "1"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.751028345064026*^9, 3.751028354222678*^9}}],

Cell[BoxData["x"], "Output",
 CellChangeTimes->{{3.751028347081374*^9, 3.7510283552074866`*^9}, 
   3.7510299586236744`*^9, 3.7510423358000417`*^9, 3.751042415763239*^9, 
   3.751046958366488*^9, {3.751115898638932*^9, 3.7511159080932894`*^9}, 
   3.7511181033309994`*^9, 3.751118966628108*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"back", " ", 
    RowBox[{"transformation", " ", ":", " ", "Ansatz"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"yBack", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["I", "w0"]}], "+", 
          RowBox[{"I", " ", "d10im"}]}], ")"}], 
        RowBox[{"-", "1"}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Z", "-", "Zbar"}], ")"}], "/", "2"}]}], "+", 
      RowBox[{"f1", " ", 
       SuperscriptBox["Z", "3"]}], "+", 
      RowBox[{"f2", " ", 
       SuperscriptBox["Z", "2"], "Zbar"}], " ", "+", 
      RowBox[{"f3", " ", "Z", " ", 
       SuperscriptBox["Zbar", "2"]}], "+", 
      RowBox[{"f4", " ", 
       SuperscriptBox["Zbar", "3"]}]}], "//", "Simplify"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.751005830424132*^9, 3.7510058462275314`*^9}, {
  3.7510063668988276`*^9, 3.751006391274252*^9}, {3.7510283753220634`*^9, 
  3.751028413940456*^9}, {3.751028574926345*^9, 3.751028588856433*^9}, {
  3.751029967461625*^9, 3.7510299684001017`*^9}, {3.751046987896816*^9, 
  3.751046989040033*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"expand", " ", "to", " ", "third", " ", "order"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"yBack2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"yBack", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "\[Rule]", 
              RowBox[{"\[Epsilon]", " ", "x"}]}], ",", 
             RowBox[{"y", "\[Rule]", 
              RowBox[{"\[Epsilon]", " ", "y"}]}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]", ",", "0", ",", "3"}], "}"}]}], "]"}], "//", 
        "Normal"}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]", "\[Rule]", "1"}], "}"}]}], "//", "Expand"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.7510064026688004`*^9, 3.751006407719971*^9}, 
   3.7510284323710546`*^9, {3.751029970201854*^9, 3.7510299762688093`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "solve", " ", "for", " ", "unknown", " ", "coefficients", " ", "in", " ", 
    "back", " ", "transformation"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"fsol", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"yBack2", ",", 
            SuperscriptBox["x", "3"]}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"yBack2", ",", 
            RowBox[{
             SuperscriptBox["x", "2"], "y"}]}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"yBack2", ",", 
            RowBox[{"x", " ", 
             SuperscriptBox["y", "2"]}]}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"yBack2", ",", 
            SuperscriptBox["y", "3"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"f1", ",", "f2", ",", "f3", ",", "f4"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.751006425856019*^9, 3.7510064608811345`*^9}, {
  3.751028444864707*^9, 3.7510284591926575`*^9}, {3.7510285995702257`*^9, 
  3.751028602403526*^9}, {3.751029988831481*^9, 3.7510299905175543`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "formal", " ", "representation", " ", "of", " ", "back", " ", 
    "transformation"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"yBack0", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["I", "w0"]}], "+", 
           RowBox[{"I", " ", "d10im"}]}], ")"}], 
         RowBox[{"-", "1"}]], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Z0", "-", "Z0bar"}], ")"}], "/", "2"}]}], "+", 
       RowBox[{"f1", " ", 
        SuperscriptBox["Z0", "3"]}], "+", 
       RowBox[{"f2", " ", 
        SuperscriptBox["Z0", "2"], "Z0bar"}], " ", "+", 
       RowBox[{"f3", " ", "Z0", " ", 
        SuperscriptBox["Z0bar", "2"]}], "+", 
       RowBox[{"f4", " ", 
        SuperscriptBox["Z0bar", "3"]}]}], "/.", "fsol"}], "//", 
     "Simplify"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.7510064942096577`*^9, 3.75100652655909*^9}, {
   3.7510066759327145`*^9, 3.7510066770432367`*^9}, 3.751028714836217*^9, {
   3.7510300069144073`*^9, 3.751030007832291*^9}, {3.7510469952470083`*^9, 
   3.751046996197324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Sanity", " ", "check"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"yBack0", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Z0", "\[Rule]", "Z"}], ",", 
            RowBox[{"Z0bar", "\[Rule]", "Zbar"}]}], "}"}]}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "\[Rule]", 
           RowBox[{"\[Epsilon]", " ", "x"}]}], ",", 
          RowBox[{"y", "\[Rule]", 
           RowBox[{"\[Epsilon]", " ", "y"}]}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", "0", ",", "3"}], "}"}]}], "]"}], "//", 
     "Normal"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{"\[Epsilon]", "\[Rule]", "1"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.751028210953533*^9, 3.7510282882391915`*^9}, {
  3.7510283333814764`*^9, 3.7510283363043594`*^9}, {3.7510287236613655`*^9, 
  3.751028726878298*^9}}],

Cell[BoxData["y"], "Output",
 CellChangeTimes->{{3.7510282130563374`*^9, 3.751028288608074*^9}, 
   3.7510284631177807`*^9, 3.751028605174884*^9, {3.751028719746949*^9, 
   3.7510287273257217`*^9}, 3.751030011219965*^9, 3.7510424371146355`*^9, 
   3.7510469663312635`*^9, 3.751046997723852*^9, 3.751115918975427*^9, 
   3.7511181079809504`*^9, 3.751118972973051*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Equation for ",
 Cell[BoxData[
  FormBox[
   FractionBox["dZ", "dt"], TraditionalForm]]]
}], "Subsection",
 CellChangeTimes->{{3.751042545230399*^9, 3.7510425549531097`*^9}, {
  3.751042945021888*^9, 3.751042946469963*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"formal", " ", "derivative", " ", "of", " ", "Z"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"dZ", "=", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"Z", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "\[Rule]", 
           RowBox[{"x", "[", "t", "]"}]}], ",", 
          RowBox[{"y", "\[Rule]", 
           RowBox[{"y", "[", "t", "]"}]}]}], "}"}]}], ",", "t"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], "\[Rule]", "dx"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "'"}], "[", "t", "]"}], "\[Rule]", "dy"}], ",", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "\[Rule]", "x"}], ",", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "\[Rule]", "y"}]}], "}"}]}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.7510026857274494`*^9, 3.75100272946274*^9}, {
   3.7510030264325867`*^9, 3.7510030329231424`*^9}, 3.751047005409005*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"substitute", " ", 
     RowBox[{
      RowBox[{"y", "'"}], "[", "t", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
     "using", " ", "the", " ", "differential", " ", "equation", " ", "of", 
      " ", "the", " ", "van"}], "-", 
     RowBox[{"der", " ", "Pol", " ", "oscillator"}]}], ",", " ", 
    RowBox[{
     SuperscriptBox["w0", "2"], "=", 
     RowBox[{"k", "/", "m"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"dyexp", "=", 
    RowBox[{
     RowBox[{
      FractionBox["\[Gamma]", "m"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[CapitalLambda]", "4"], "-", 
        SuperscriptBox["x", "2"]}], ")"}], "y"}], " ", "-", 
     RowBox[{
      SuperscriptBox["w0", "2"], "x"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.751002761366596*^9, 3.7510027959979315`*^9}, {
   3.751003034803959*^9, 3.7510030896715417`*^9}, 3.7510281792971954`*^9, {
   3.751030034825675*^9, 3.7510300382986126`*^9}, {3.751042456812274*^9, 
   3.7510424593840017`*^9}, 3.751115927099962*^9, {3.7511181325206923`*^9, 
   3.751118132589697*^9}, {3.7511189785094476`*^9, 3.7511189785625057`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"massage", " ", "derivative", " ", "of", " ", "Z"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"dZ2", "=", 
    RowBox[{"dZ", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"dy", "\[Rule]", "dyexp"}], ",", 
       RowBox[{"dx", "\[Rule]", "y"}]}], "}"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.751002797576702*^9, 3.751002804217476*^9}, {
   3.7510028387510366`*^9, 3.7510028402832613`*^9}, {3.751003094775667*^9, 
   3.751003132216485*^9}, 3.7510470147219515`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "express", " ", "x", " ", "and", " ", "y", " ", "by", " ", "Z", " ", 
     "and", " ", "its", " ", "complex", " ", "conjugate"}], ",", " ", 
    RowBox[{"Caution", ":", " ", 
     RowBox[{"symbol", " ", "Z", " ", "already", " ", "used"}]}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"dZ3", "=", 
    RowBox[{"dZ2", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "xBack0"}], ",", 
       RowBox[{"y", "\[Rule]", "yBack0"}]}], "}"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.7510028419373136`*^9, 3.751002851623384*^9}, {
   3.751002882302059*^9, 3.751002942217886*^9}, {3.7510031584469223`*^9, 
   3.751003187501782*^9}, {3.75100343684858*^9, 3.751003464335809*^9}, 
   3.75100384732959*^9, {3.7510065678494864`*^9, 3.751006585401467*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dZ4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"dZ3", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Z0", "\[Rule]", 
              RowBox[{"\[Epsilon]", " ", "Z0"}]}], ",", 
             RowBox[{"Z0bar", "\[Rule]", 
              RowBox[{"\[Epsilon]", " ", "Z0bar"}]}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]", ",", "0", ",", "3"}], "}"}]}], "]"}], "//", 
        "Normal"}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]", "\[Rule]", "1"}], "}"}]}], "//", "Expand"}], "//",
     "Simplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7510065980731716`*^9, 3.751006651982752*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Determine coefficients of forward transformation ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"x", 
    RowBox[{"(", 
     RowBox[{"Z", ",", 
      OverscriptBox["Z", "_"]}], ")"}]}]}]], "Input",
  CellChangeTimes->{{3.7510428737473073`*^9, 3.7510428737502956`*^9}}],
 ",",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"y", "=", 
    RowBox[{"y", 
     RowBox[{"(", 
      RowBox[{"Z", ",", 
       OverscriptBox["Z", "_"]}], ")"}]}]}]}]], "Input",
  CellChangeTimes->{{3.7510428737473073`*^9, 3.7510428737502956`*^9}}],
 " such that all coefficients of ",
 Cell[BoxData[
  FormBox[
   FractionBox["dZ", "dt"], TraditionalForm]]],
 " vanish, \[LineSeparator]excepts those for Z and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["Z", "2"], 
    OverscriptBox["Z", "_"]}], TraditionalForm]]]
}], "Subsection",
 CellChangeTimes->{{3.7510425951652555`*^9, 3.7510427629707966`*^9}, {
  3.75104279371204*^9, 3.7510428504103994`*^9}, {3.751042881453126*^9, 
  3.7510429587834115`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"coefficient", " ", "of", " ", 
    RowBox[{"Z", ":", " ", 
     RowBox[{"looks", " ", "good"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"F", "=", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"dZ4", ",", "Z0"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"Z0bar", "\[Rule]", "0"}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.751002950644351*^9, 3.7510029607446814`*^9}, {
  3.751003200527649*^9, 3.7510032049528093`*^9}, {3.75100394014209*^9, 
  3.7510039472636642`*^9}, {3.7510044776389303`*^9, 3.7510044781397257`*^9}, {
  3.751006657204095*^9, 3.751006658505748*^9}, {3.75104298858817*^9, 
  3.7510430072735205`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"32", " ", "m", " ", "w0"}], "-", 
     RowBox[{"128", " ", "d10im", " ", "m", " ", 
      SuperscriptBox["w0", "2"]}], "+", 
     RowBox[{"208", " ", 
      SuperscriptBox["d10im", "2"], " ", "m", " ", 
      SuperscriptBox["w0", "3"]}], "-", 
     RowBox[{"176", " ", 
      SuperscriptBox["d10im", "3"], " ", "m", " ", 
      SuperscriptBox["w0", "4"]}], "+", 
     RowBox[{"80", " ", 
      SuperscriptBox["d10im", "4"], " ", "m", " ", 
      SuperscriptBox["w0", "5"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["d10im", "5"], " ", "m", " ", 
      SuperscriptBox["w0", "6"]}], "-", 
     RowBox[{
     "4", " ", "\[ImaginaryI]", " ", "\[Gamma]", " ", "\[CapitalLambda]"}], 
     "+", 
     RowBox[{
     "16", " ", "\[ImaginaryI]", " ", "d10im", " ", "w0", " ", "\[Gamma]", 
      " ", "\[CapitalLambda]"}], "-", 
     RowBox[{"24", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["d10im", "2"], " ", 
      SuperscriptBox["w0", "2"], " ", "\[Gamma]", " ", "\[CapitalLambda]"}], 
     "+", 
     RowBox[{"16", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["d10im", "3"], " ", 
      SuperscriptBox["w0", "3"], " ", "\[Gamma]", " ", "\[CapitalLambda]"}], 
     "-", 
     RowBox[{"4", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["d10im", "4"], " ", 
      SuperscriptBox["w0", "4"], " ", "\[Gamma]", " ", "\[CapitalLambda]"}]}],
     ")"}]}], 
  RowBox[{"32", " ", "m", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"d10im", " ", "w0"}]}], ")"}], "4"]}]]], "Output",
 CellChangeTimes->{
  3.7510029610982594`*^9, {3.751003190239445*^9, 3.751003205400693*^9}, {
   3.751003440919072*^9, 3.7510034670380616`*^9}, 3.7510039482961035`*^9, 
   3.7510041692327366`*^9, 3.7510042263409815`*^9, 3.75100439450662*^9, 
   3.7510044792723455`*^9, 3.751005419886711*^9, 3.7510066593074636`*^9, 
   3.7510066931640797`*^9, {3.751006833959739*^9, 3.7510068563599606`*^9}, 
   3.751028752615681*^9, 3.7510300921015363`*^9, 3.7510424678780537`*^9, {
   3.7510429928233814`*^9, 3.751043007814823*^9}, 3.751047027533581*^9, 
   3.7511159413013096`*^9, 3.7511181139247503`*^9, 3.7511181691530495`*^9, 
   3.7511189835372815`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "this", " ", "coefficient", " ", "vanishes", " ", "by", " ", "proper", 
     " ", "choice", " ", "of", " ", "d10im"}], ",", " ", 
    RowBox[{"as", " ", "it", " ", "should"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"eqn0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"dZ4", ",", "Z0bar"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{"Z0", "\[Rule]", "0"}], "}"}]}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.751003360072991*^9, 3.7510033624694047`*^9}, {
  3.7510039490802145`*^9, 3.7510039589535785`*^9}, {3.751004405110938*^9, 
  3.7510044061622534`*^9}, {3.7510052871520596`*^9, 3.7510052959158707`*^9}, {
  3.751006707241826*^9, 3.751006709627822*^9}, {3.7510068221882925`*^9, 
  3.751006822288235*^9}, {3.7510470466882935`*^9, 3.751047047722653*^9}, {
  3.751047090655922*^9, 3.7510470908204513`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"8", " ", "\[ImaginaryI]", " ", "d10im", " ", "m", " ", 
     SuperscriptBox["w0", "2"]}], "-", 
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["d10im", "2"], " ", "m", " ", 
     SuperscriptBox["w0", "3"]}], "+", 
    RowBox[{"\[Gamma]", " ", "\[CapitalLambda]"}], "-", 
    RowBox[{"d10im", " ", "w0", " ", "\[Gamma]", " ", "\[CapitalLambda]"}]}], 
   RowBox[{
    RowBox[{"8", " ", "m"}], "-", 
    RowBox[{"8", " ", "d10im", " ", "m", " ", "w0"}]}]]}]], "Output",
 CellChangeTimes->{
  3.75100336283643*^9, {3.7510034420005064`*^9, 3.751003468307396*^9}, 
   3.7510039593200417`*^9, 3.7510041708495364`*^9, 3.7510042287431955`*^9, {
   3.7510043982552104`*^9, 3.751004407648628*^9}, 3.7510049909060144`*^9, 
   3.751005421188653*^9, {3.7510066994711514`*^9, 3.75100670999685*^9}, {
   3.751006822888796*^9, 3.7510068577617645`*^9}, 3.7510287540471554`*^9, {
   3.7510300938647895`*^9, 3.7510301058121276`*^9}, 3.751042470428015*^9, 
   3.7510430104007*^9, 3.751047048359784*^9, 3.7510470911449785`*^9, 
   3.7511159593607283`*^9, 3.7511181703260956`*^9, 3.7511189848728285`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d10imsol", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"eqn0", "\[Equal]", "0"}], ",", "d10im"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7510044093654766`*^9, 3.7510044181609974`*^9}, {
  3.7510044511084404`*^9, 3.751004452339552*^9}, {3.7510067120161324`*^9, 
  3.751006713849844*^9}, {3.751006863119236*^9, 3.751006867070017*^9}, {
  3.7510470506399364`*^9, 3.7510470788369613`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"d10im", "\[Rule]", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", "\[ImaginaryI]", " ", "m", " ", 
        SuperscriptBox["w0", "2"]}], "+", 
       RowBox[{"w0", " ", "\[Gamma]", " ", "\[CapitalLambda]"}], "-", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "64"}], " ", 
          SuperscriptBox["m", "2"], " ", 
          SuperscriptBox["w0", "4"]}], "+", 
         RowBox[{
          SuperscriptBox["w0", "2"], " ", 
          SuperscriptBox["\[Gamma]", "2"], " ", 
          SuperscriptBox["\[CapitalLambda]", "2"]}]}]]}], ")"}]}], 
    RowBox[{"8", " ", "m", " ", 
     SuperscriptBox["w0", "3"]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7510044141106186`*^9, 3.751004418544813*^9}, 
   3.7510044527285995`*^9, 3.7510049918336287`*^9, 3.751005422472223*^9, {
   3.7510067028440332`*^9, 3.751006714550234*^9}, 3.751006867438773*^9, 
   3.7510287559705243`*^9, {3.75103009786913*^9, 3.7510301077640324`*^9}, 
   3.751042472326734*^9, 3.7510430124016495`*^9, {3.7510470578392982`*^9, 
   3.7510470921623507`*^9}, 3.7511159628344336`*^9, 3.751118171677469*^9, 
   3.751118986199716*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F2", "=", 
  RowBox[{
   RowBox[{"F", "/.", "d10imsol"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.751004483360203*^9, 3.7510044931093445`*^9}, {
  3.7510068714888*^9, 3.751006871642007*^9}, {3.751026840817623*^9, 
  3.751026841417697*^9}, {3.751047099594125*^9, 3.751047100505147*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"32", " ", 
    SuperscriptBox["m", "2"], " ", 
    SuperscriptBox["w0", "3"]}], "+", 
   RowBox[{"\[Gamma]", " ", "\[CapitalLambda]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "w0"}], " ", "\[Gamma]", " ", "\[CapitalLambda]"}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "64"}], " ", 
         SuperscriptBox["m", "2"], " ", 
         SuperscriptBox["w0", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["\[Gamma]", "2"], " ", 
         SuperscriptBox["\[CapitalLambda]", "2"]}]}]]}], ")"}]}]}], 
  RowBox[{"m", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "w0", " ", "\[Gamma]", " ", 
      "\[CapitalLambda]"}], "+", 
     RowBox[{"4", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "64"}], " ", 
         SuperscriptBox["m", "2"], " ", 
         SuperscriptBox["w0", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["w0", "2"], " ", 
         SuperscriptBox["\[Gamma]", "2"], " ", 
         SuperscriptBox["\[CapitalLambda]", "2"]}]}]]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.7510044884342175`*^9, 3.7510044939415846`*^9}, 
   3.751004994091899*^9, 3.7510054237763925`*^9, 3.751006716204675*^9, 
   3.7510068720265484`*^9, 3.7510268418492737`*^9, 3.751028763276985*^9, 
   3.751030111280391*^9, 3.7510424741693707`*^9, 3.7510430152816744`*^9, {
   3.751047093260027*^9, 3.751047101041234*^9}, 3.751115964253102*^9, 
   3.7511181730557785`*^9, 3.751118987485594*^9},
 Background->GrayLevel[0.85]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"quadratic", " ", 
     RowBox[{"terms", ":", " ", 
      RowBox[{"coefficients", " ", "are", " ", "zero"}]}]}], ";", " ", 
    RowBox[{"this", " ", "is", " ", "fine"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"dZ3", ",", 
      SuperscriptBox["Z0", "2"]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"Z0bar", "\[Rule]", "0"}], "}"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.751003536397524*^9, 3.751003555747339*^9}, {
   3.7510040180674953`*^9, 3.7510040432254944`*^9}, {3.7510067245263796`*^9, 
   3.7510067267786775`*^9}, {3.751043025590667*^9, 3.751043027328038*^9}, 
   3.7510471091216264`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.751003541951418*^9, 3.7510035776646795`*^9}, {
   3.7510039605367827`*^9, 3.7510039900869846`*^9}, 3.7510040442265477`*^9, 
   3.751004172297449*^9, 3.7510045189444833`*^9, 3.7510049762577634`*^9, 
   3.7510054262261095`*^9, {3.751006721408396*^9, 3.7510067271609983`*^9}, 
   3.751006875545024*^9, 3.751028778266819*^9, 3.751030115621092*^9, 
   3.751042476534043*^9, {3.751043019955056*^9, 3.7510430278910327`*^9}, 
   3.7510471056190987`*^9, 3.7511159679738045`*^9, 3.751118174441349*^9, 
   3.751118988439599*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{"dZ3", ",", 
    RowBox[{"Z0", " ", "Z0bar"}]}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.751003588188986*^9, 3.7510035966884117`*^9}, {
   3.7510036627168465`*^9, 3.751003675427492*^9}, {3.7510039878015165`*^9, 
   3.7510039881836085`*^9}, 3.751006733901641*^9, 3.7510471123912*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.75100359716481*^9, 3.7510036758750086`*^9, 
  3.7510039909348125`*^9, 3.7510040451217766`*^9, 3.751004173367117*^9, 
  3.7510045227954636`*^9, 3.751004977180031*^9, 3.7510054295133886`*^9, 
  3.751006734348665*^9, 3.7510068786647997`*^9, 3.7510287793527994`*^9, 
  3.751042477456785*^9, 3.7510430289462805`*^9, 3.7510471128756742`*^9, 
  3.7511159690970864`*^9, 3.7511181760952053`*^9, 3.751118989137704*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"dZ3", ",", 
     SuperscriptBox["Z0bar", "2"]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{"Z0", "\[Rule]", "0"}], "}"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7510035665558877`*^9, 3.751003581214402*^9}, 
   3.751006736689129*^9, 3.751047114726898*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.751003569404847*^9, 3.7510035838004313`*^9}, 
   3.751003991751013*^9, 3.751004045929021*^9, 3.7510041743138328`*^9, 
   3.7510045239337406`*^9, 3.7510049806783996`*^9, 3.7510054316407614`*^9, 
   3.7510067371883125`*^9, 3.751006880798725*^9, 3.7510287800911098`*^9, 
   3.7510424785047283`*^9, 3.7510430298311357`*^9, 3.751047115155303*^9, 
   3.751115969729006*^9, 3.7511181772583475`*^9, 3.7511189896707926`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "cubic", " ", "terms", " ", "b3", " ", "and", " ", "c3", " ", "can", " ", 
    "be", " ", "chosen", " ", "such", " ", "that", " ", "these", " ", 
    "expressions", " ", "are", " ", "zero"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqn1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"dZ3", ",", 
        SuperscriptBox["Z0", "3"]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{"Z0bar", "\[Rule]", "0"}], "}"}]}], "//", "Simplify"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.7510037068540287`*^9, 3.751003710419097*^9}, {
  3.7510038057958794`*^9, 3.7510038263484497`*^9}, {3.751004049278574*^9, 
  3.751004058669656*^9}, {3.7510067468293233`*^9, 3.751006750847089*^9}, {
  3.75104711759099*^9, 3.751047117667153*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqn2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"dZ3", ",", 
       SuperscriptBox["Z0bar", "3"]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{"Z0", "\[Rule]", "0"}], "}"}]}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.751003727316491*^9, 3.751003735939099*^9}, {
  3.7510067526793723`*^9, 3.7510067559660187`*^9}, {3.751047124298294*^9, 
  3.7510471243867197`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqn3", "=", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"dZ3", ",", 
      RowBox[{"Z0", " ", 
       SuperscriptBox["Z0bar", "2"]}]}], "]"}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.751006929397869*^9, 3.7510069320096474`*^9}, {
  3.751047127855797*^9, 3.7510471279558945`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"solve", " ", "for", " ", "coefficients"}], ";", " ", 
    RowBox[{"note", ":", " ", 
     RowBox[{
     "some", " ", "coefficients", " ", "can", " ", "be", " ", "chosen", " ", 
      "arbitrarily"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"d3sol", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"eqn1", "\[Equal]", "0"}], ",", 
          RowBox[{"eqn2", "\[Equal]", "0"}], ",", 
          RowBox[{"eqn3", "\[Equal]", "0"}], ",", 
          RowBox[{"d33re", "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"0", "d33im"}], "\[Equal]", "0"}], ",", 
          RowBox[{"d32re", "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"0", "d32im"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"0", "d31re"}], "\[Equal]", "0"}], ",", 
          RowBox[{"d31im", "\[Equal]", "0"}], ",", 
          RowBox[{"d30re", "\[Equal]", "0"}], ",", 
          RowBox[{"d30im", "\[Equal]", "0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "d33re", ",", "d33im", ",", "d32re", ",", "d32im", ",", "d31re", ",",
           "d31im", ",", "d30re", ",", "d30im"}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.7510038912771163`*^9, 3.7510039033080797`*^9}, {
   3.7510045658341846`*^9, 3.7510045864923563`*^9}, {3.7510068971456947`*^9, 
   3.7510069693757887`*^9}, {3.7510070685261345`*^9, 
   3.7510070826566086`*^9}, {3.7510071817634697`*^9, 
   3.7510071818637776`*^9}, {3.7510301413103757`*^9, 
   3.7510301529372454`*^9}, {3.7510302356753445`*^9, 3.751030241295444*^9}, {
   3.75103028837177*^9, 3.7510302884212933`*^9}, {3.7510430440270033`*^9, 
   3.7510430521979623`*^9}, {3.7510451214303656`*^9, 
   3.7510451458573914`*^9}, {3.751045201068695*^9, 3.751045218964755*^9}, {
   3.751045261382061*^9, 3.7510452761501904`*^9}, {3.751045374662427*^9, 
   3.751045383558535*^9}, 3.7510454600929737`*^9, {3.751045636053882*^9, 
   3.7510456980272684`*^9}, {3.7510471378429956`*^9, 3.751047194915655*^9}, {
   3.7510472379489927`*^9, 3.7510473560474634`*^9}, {3.7510474527837396`*^9, 
   3.751047479659382*^9}, {3.7511161126804934`*^9, 3.7511161138067317`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"numerical", " ", 
    RowBox[{"example", ":", " ", 
     RowBox[{
     "becomes", " ", "singular", " ", "if", " ", "we", " ", "do", " ", "not", 
      " ", "choose", " ", "the", " ", "right", " ", "coefficients", " ", "to",
       " ", "solve", " ", "for"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"w0sub", ":=", 
    RowBox[{"{", 
     RowBox[{"w0", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"k", "/", "m"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"d3sol", "//.", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"d10imsol", ",", "w0sub", ",", "d3sol"}], "}"}], "]"}]}], "/.",
      "vals"}], "//", "N"}]}]}]], "Input",
 CellChangeTimes->{{3.751047211005721*^9, 3.751047230034583*^9}, {
  3.7511159989398575`*^9, 3.751116008912055*^9}, {3.751116604472867*^9, 
  3.75111662896163*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.`", "\[Rule]", "0.`"}], ",", 
   RowBox[{
    RowBox[{"1.376758334221415`", "\[VeryThinSpace]", "+", 
     RowBox[{"0.23076923076922978`", " ", "\[ImaginaryI]"}]}], "\[Rule]", 
    RowBox[{"1.376758334221415`", "\[VeryThinSpace]", "+", 
     RowBox[{"0.23076923076922978`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{"0.`", "\[Rule]", "0.`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.710584946694924`"}], "+", 
     RowBox[{"0.46153846153846156`", " ", "\[ImaginaryI]"}]}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "0.710584946694924`"}], "+", 
     RowBox[{"0.46153846153846156`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.6153846153846153`", "\[VeryThinSpace]", "+", 
     RowBox[{"0.1776462366737311`", " ", "\[ImaginaryI]"}]}], "\[Rule]", 
    RowBox[{"0.6153846153846153`", "\[VeryThinSpace]", "+", 
     RowBox[{"0.1776462366737311`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{"0.`", "\[Rule]", "0.`"}], ",", 
   RowBox[{"0.`", "\[Rule]", "0.`"}], ",", 
   RowBox[{"0.`", "\[Rule]", "0.`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.751045115714384*^9, 3.7510451514855785`*^9}, {
   3.751045204270157*^9, 3.751045220955685*^9}, {3.751045269046692*^9, 
   3.7510452781030416`*^9}, 3.7510453866547456`*^9, 3.7510454624786797`*^9, {
   3.751045637871374*^9, 3.7510456999140916`*^9}, 3.7510458012058363`*^9, 
   3.7510459169792404`*^9, {3.7510472220502453`*^9, 3.7510472594235044`*^9}, 
   3.751047336424127*^9, 3.751047415767812*^9, {3.7510474563338814`*^9, 
   3.7510474820112295`*^9}, {3.75111597438111*^9, 3.7511160092807703`*^9}, {
   3.7511161358453293`*^9, 3.751116219407876*^9}, 3.7511166299318185`*^9, 
   3.751118180863316*^9, 3.751118993441573*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"coefficient", " ", "of", " ", 
     SuperscriptBox["Z", "2"], "Zbar"}], ";", " ", 
    RowBox[{
     RowBox[{"this", " ", "should", " ", "be", " ", "non"}], "-", "zero"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"G", "=", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"dZ3", ",", 
       RowBox[{
        SuperscriptBox["Z0", "2"], " ", "Z0bar"}]}], "]"}], "//", 
     "Simplify"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.7510036226633434`*^9, 3.751003659511959*^9}, {
   3.751003883241737*^9, 3.751003883310302*^9}, 3.7510046877829723`*^9, {
   3.7510047838071504`*^9, 3.7510047842760515`*^9}, {3.751004857515629*^9, 
   3.7510048583313246`*^9}, {3.751006772183086*^9, 3.751006775406642*^9}, {
   3.7510302801297336`*^9, 3.7510302841013503`*^9}, {3.7510430572387323`*^9, 
   3.75104307082755*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G2", "=", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"G", "/.", "d3sol"}], ",", 
    RowBox[{"d10imsol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7510069952221255`*^9, 3.751006999720762*^9}, {
  3.751007090265259*^9, 3.751007144734039*^9}, {3.751026845389204*^9, 
  3.751026846368451*^9}, {3.75104749699088*^9, 3.751047500689307*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"16", " ", "m", " ", 
    SuperscriptBox["w0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"32", " ", 
       SuperscriptBox["m", "2"], " ", 
       SuperscriptBox["w0", "3"], " ", "\[Gamma]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], " ", "\[CapitalLambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "w0"}], " ", "\[Gamma]", " ", "\[CapitalLambda]"}], 
         "+", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "64"}], " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["w0", "4"]}], "+", 
           RowBox[{
            SuperscriptBox["w0", "2"], " ", 
            SuperscriptBox["\[Gamma]", "2"], " ", 
            SuperscriptBox["\[CapitalLambda]", "2"]}]}]]}], ")"}]}]}], 
     ")"}]}], 
   RowBox[{
    RowBox[{"4096", " ", 
     SuperscriptBox["m", "4"], " ", 
     SuperscriptBox["w0", "5"]}], "+", 
    RowBox[{"w0", " ", 
     SuperscriptBox["\[Gamma]", "4"], " ", 
     SuperscriptBox["\[CapitalLambda]", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["\[Gamma]", "3"], " ", 
     SuperscriptBox["\[CapitalLambda]", "3"], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "64"}], " ", 
        SuperscriptBox["m", "2"], " ", 
        SuperscriptBox["w0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["w0", "2"], " ", 
        SuperscriptBox["\[Gamma]", "2"], " ", 
        SuperscriptBox["\[CapitalLambda]", "2"]}]}]]}], "+", 
    RowBox[{"32", " ", 
     SuperscriptBox["m", "2"], " ", 
     SuperscriptBox["w0", "2"], " ", "\[Gamma]", " ", "\[CapitalLambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "w0", " ", "\[Gamma]", " ", 
        "\[CapitalLambda]"}], "+", 
       RowBox[{"3", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "64"}], " ", 
           SuperscriptBox["m", "2"], " ", 
           SuperscriptBox["w0", "4"]}], "+", 
          RowBox[{
           SuperscriptBox["w0", "2"], " ", 
           SuperscriptBox["\[Gamma]", "2"], " ", 
           SuperscriptBox["\[CapitalLambda]", "2"]}]}]]}]}], 
      ")"}]}]}]]}]], "Output",
 CellChangeTimes->{
  3.751007000086562*^9, {3.7510070863445387`*^9, 3.7510071457351565`*^9}, 
   3.751007185935566*^9, 3.75102684666825*^9, 3.7510287908376145`*^9, 
   3.751030160581961*^9, 3.7510302458988123`*^9, 3.751030292994608*^9, {
   3.751030341561802*^9, 3.751030349315877*^9}, 3.751043073616377*^9, {
   3.7510474917908535`*^9, 3.751047502158969*^9}, 3.751116013430606*^9, 
   3.751116636766862*^9, 3.7511181843520727`*^9, 3.751118265848117*^9, 
   3.7511189956380873`*^9},
 Background->GrayLevel[0.85]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpret results", "Subsection",
 CellChangeTimes->{{3.7510431446723824`*^9, 3.751043153161418*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"frequency", " ", "[", 
    RowBox[{"leading", " ", "order", " ", "term"}], "]"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Im", "[", "F2", "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[CapitalLambda]", "\[Rule]", "0"}], "}"}]}], "//", 
     "ComplexExpand"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.751027742226635*^9, 3.7510277474147654`*^9}, {
  3.7510288511600504`*^9, 3.7510288632124677`*^9}, {3.7510431750278053`*^9, 
  3.751043193625572*^9}, {3.751116651839958*^9, 3.7511166561691885`*^9}}],

Cell[BoxData[
 RowBox[{"-", "w0"}]], "Output",
 CellChangeTimes->{
  3.7510277481315584`*^9, {3.7510288440748196`*^9, 3.7510288638136206`*^9}, 
   3.7510301621839542`*^9, 3.7510302473371415`*^9, 3.7510302943266797`*^9, 
   3.751030350300521*^9, 3.7510430758348465`*^9, 3.751047505597105*^9, {
   3.7511166675786457`*^9, 3.751116671714077*^9}, 3.7511181855910997`*^9, 
   3.7511182682133875`*^9, 3.751118996724017*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"expand", " ", "F2"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"F2series", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"F2", ",", 
     RowBox[{"{", 
      RowBox[{"\[CapitalLambda]", ",", "0", ",", "1"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.751029013151469*^9, 3.7510290603415785`*^9}, {
  3.7510291061157703`*^9, 3.751029126510408*^9}, {3.7510432268862896`*^9, 
  3.751043233092177*^9}, {3.7510434406873455`*^9, 3.7510434524741745`*^9}, {
  3.7510435365129485`*^9, 3.751043539192252*^9}, {3.751116675285119*^9, 
  3.75111668058961*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["m", "2"]}], " ", 
       SuperscriptBox["w0", "4"]}]], 
     RowBox[{"m", " ", "w0"}]]}], "+", 
   FractionBox[
    RowBox[{"\[Gamma]", " ", "\[CapitalLambda]"}], 
    RowBox[{"8", " ", "m"}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[CapitalLambda]", "]"}], "2"],
    SeriesData[$CellContext`\[CapitalLambda], 0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[CapitalLambda], 
   0, {-$CellContext`m^(-1) $CellContext`w0^(-1) (-$CellContext`m^2 \
$CellContext`w0^4)^Rational[1, 2], 
    Rational[1, 8] $CellContext`m^(-1) $CellContext`\[Gamma]}, 0, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7510290142347326`*^9, {3.75102904486543*^9, 3.7510290607000384`*^9}, {
   3.7510291166712246`*^9, 3.751029127164894*^9}, 3.751030163162817*^9, 
   3.7510302481853375`*^9, 3.7510302952265434`*^9, 3.751030351039833*^9, 
   3.75104309040484*^9, 3.7510434528009787`*^9, 3.751043540663101*^9, 
   3.751047506738892*^9, 3.751116680989855*^9, 3.7511181877603264`*^9, 
   3.7511182692664876`*^9, 3.751118396132115*^9, 3.751118998015415*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"negative", " ", "damping", " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"F2series", "//", "Normal"}], "]"}], "//", 
   "ComplexExpand"}]}]], "Input",
 CellChangeTimes->{{3.75104354665407*^9, 3.7510435853126745`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Gamma]", " ", "\[CapitalLambda]"}], 
  RowBox[{"8", " ", "m"}]]], "Output",
 CellChangeTimes->{{3.7510435525251465`*^9, 3.7510435857459373`*^9}, 
   3.7510475084176846`*^9, 3.7511166842238812`*^9, 3.75111818975899*^9, 
   3.751118270318019*^9, 3.7511183978457127`*^9, 3.7511190000937347`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"amplitude", "-", 
    RowBox[{"dependent", " ", 
     RowBox[{"damping", " ", "[", 
      RowBox[{"leading", " ", "order", " ", "term"}], "]"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Re", "[", "G2", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"\[CapitalLambda]", "\[Rule]", "0"}], "}"}]}], "//", 
   "ComplexExpand"}]}]], "Input",
 CellChangeTimes->{{3.7510274258937445`*^9, 3.7510274354662733`*^9}, {
  3.7510289759159575`*^9, 3.751028983273386*^9}, {3.751043598309719*^9, 
  3.7510436204775696`*^9}, {3.7511166915457544`*^9, 3.75111669241493*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["\[Gamma]", 
   RowBox[{"8", " ", "m"}]]}]], "Output",
 CellChangeTimes->{
  3.751027435867354*^9, 3.751028983605999*^9, 3.7510301728092623`*^9, 
   3.7510302579932337`*^9, 3.7510302963972344`*^9, 3.7510430944928207`*^9, 
   3.7510436084976745`*^9, {3.7510475096118526`*^9, 3.751047530830456*^9}, {
   3.751116693153186*^9, 3.751116695264324*^9}, {3.751118191229021*^9, 
   3.751118192830063*^9}, 3.7511182713420453`*^9, 3.751118398618814*^9, 
   3.7511190015731306`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"non", "-", 
    RowBox[{"isochrony", " ", 
     RowBox[{"parameter", " ", "[", 
      RowBox[{"leading", " ", "order", " ", "term"}], "]"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Im", "[", "G2", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"\[CapitalLambda]", "\[Rule]", "0"}], "}"}]}], "//", 
   "ComplexExpand"}]}]], "Input",
 CellChangeTimes->{{3.7510274609281387`*^9, 3.7510274620652328`*^9}, {
   3.7510289962468767`*^9, 3.7510290029022365`*^9}, {3.751043611566427*^9, 
   3.7510436353262377`*^9}, 3.7511167134631443`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7510274624883175`*^9, 3.7510290032714853`*^9, 3.751030174057024*^9, 
   3.751030258893958*^9, 3.75103029726003*^9, 3.7510430957732487`*^9, 
   3.7510436358100047`*^9, {3.751047515039858*^9, 3.7510475319594383`*^9}, 
   3.7511167139942083`*^9, 3.7511182067750893`*^9, 3.751118272246689*^9, 
   3.751119006014194*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical solution", "Subchapter",
 CellChangeTimes->{{3.7510440296339645`*^9, 3.751044046046549*^9}}],

Cell[BoxData[
 RowBox[{"vals", ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"m", "\[Rule]", "1"}], ",", 
    RowBox[{"\[Gamma]", "\[Rule]", "8"}], ",", 
    RowBox[{"k", "\[Rule]", "1"}], ",", 
    RowBox[{"\[CapitalLambda]", "\[Rule]", ".05"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7510448743981495`*^9, 3.7510448769468336`*^9}, {
   3.751044921340184*^9, 3.7510449340521617`*^9}, {3.7510476289599504`*^9, 
   3.751047631015169*^9}, {3.751048405606822*^9, 3.751048408009302*^9}, {
   3.7510485389100533`*^9, 3.7510485407482615`*^9}, {3.7511182756336017`*^9, 
   3.7511182996618967`*^9}, 3.7511186421218147`*^9, {3.7511190137162714`*^9, 
   3.7511190428446264`*^9}}],

Cell[BoxData[
 RowBox[{"w0sub", ":=", 
  RowBox[{"{", 
   RowBox[{"w0", "\[Rule]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"k", "/", "m"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7510436709451804`*^9, 3.7510436997401123`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Fval", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"F2", "/.", "w0sub"}], ")"}], "/.", 
   "vals"}]}], "\[IndentingNewLine]", 
 RowBox[{"Gval", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"G2", "/.", "w0sub"}], ")"}], "/.", "vals"}]}]}], "Input",
 CellChangeTimes->{{3.7510437648835907`*^9, 3.7510437794882307`*^9}, {
  3.7510484634129205`*^9, 3.7510484866497345`*^9}}],

Cell[BoxData[
 RowBox[{"0.05000000000000001`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.9987492177719091`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.7510437672399464`*^9, 3.7510437800512013`*^9}, 
   3.7510448786024237`*^9, {3.751044910848135*^9, 3.7510449356685905`*^9}, 
   3.751047545862645*^9, 3.751047632857993*^9, 3.7510484100580797`*^9, {
   3.7510484674008865`*^9, 3.7510484877739105`*^9}, 3.7510485422972603`*^9, {
   3.751118286716165*^9, 3.7511183016529274`*^9}, 3.7511186446606646`*^9, {
   3.751119009517084*^9, 3.7511190452986555`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1.0018785222291797`"}], "-", 
  RowBox[{"0.025078330585936587`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.7510437672399464`*^9, 3.7510437800512013`*^9}, 
   3.7510448786024237`*^9, {3.751044910848135*^9, 3.7510449356685905`*^9}, 
   3.751047545862645*^9, 3.751047632857993*^9, 3.7510484100580797`*^9, {
   3.7510484674008865`*^9, 3.7510484877739105`*^9}, 3.7510485422972603`*^9, {
   3.751118286716165*^9, 3.7511183016529274`*^9}, 3.7511186446606646`*^9, {
   3.751119009517084*^9, 3.751119045314277*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"initial", " ", "conditions"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Zinit", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Z", "//.", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"w0sub", ",", "d10imsol", ",", "d3sol", ",", "vals"}], "}"}], 
       "]"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Rule]", "x0"}], ",", 
      RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.751048154754305*^9, 3.7510482531307726`*^9}, {
  3.75111833304582*^9, 3.751118334389484*^9}}],

Cell[BoxData[
 RowBox[{"0.09999962429555417`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.00200750155465628`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{
  3.7510481634157553`*^9, {3.751048204304617*^9, 3.7510482537012014`*^9}, 
   3.7510484119599547`*^9, {3.7510484687753167`*^9, 3.751048488875267*^9}, 
   3.7510485435294724`*^9, {3.7511183058349895`*^9, 3.7511183351290455`*^9}, 
   3.7511186457600193`*^9, {3.751119031073247*^9, 3.7511190465157957`*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqn", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Zre", "'"}], "[", "t", "]"}], "+", 
      RowBox[{"I", " ", 
       RowBox[{
        RowBox[{"Zim", "'"}], "[", "t", "]"}]}]}], "==", 
     RowBox[{
      RowBox[{"Fval", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Zre", "[", "t", "]"}], "+", 
         RowBox[{"I", " ", 
          RowBox[{"Zim", "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"Gval", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Zre", "[", "t", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"Zim", "[", "t", "]"}], "^", "2"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Zre", "[", "t", "]"}], "+", 
         RowBox[{"I", " ", 
          RowBox[{"Zim", "[", "t", "]"}]}]}], ")"}]}]}]}], ")"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7510436547001157`*^9, 3.7510436568811088`*^9}, {
   3.7510436918330765`*^9, 3.751043706688494*^9}, {3.7510437416887083`*^9, 
   3.751043896661207*^9}, {3.751118407474965*^9, 3.751118421754344*^9}, 
   3.751118457784253*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eqnRe", "=", 
   RowBox[{
    RowBox[{"Re", "[", "eqn", "]"}], "//", "ComplexExpand"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqnIm", "=", 
   RowBox[{
    RowBox[{"Im", "[", "eqn", "]"}], "//", "ComplexExpand"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7510438650285945`*^9, 3.751043925823757*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zsol", "=", 
   RowBox[{
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eqnRe", ",", "eqnIm", ",", 
        RowBox[{
         RowBox[{"Zre", "[", "0", "]"}], "\[Equal]", 
         RowBox[{"Re", "[", "Zinit", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Zim", "[", "0", "]"}], "\[Equal]", 
         RowBox[{"Im", "[", "Zinit", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Zre", "[", "t", "]"}], ",", 
        RowBox[{"Zim", "[", "t", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7510439278782415`*^9, 3.7510439780717893`*^9}, 
   3.751044894380878*^9, {3.751048268883424*^9, 3.7510482772586374`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Zre", "[", "t", "]"}], ",", 
        RowBox[{"Zim", "[", "t", "]"}]}], "}"}], "/.", "Zsol"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Sqrt", "[", "\[CapitalLambda]", "]"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Phi]", "]"}], ",", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "}"}]}], "/.", "vals"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Phi]", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "p2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.751043987595498*^9, 3.7510440188211765`*^9}, {
  3.7511185267578483`*^9, 3.75111865615088*^9}, {3.751119038777915*^9, 
  3.751119038893815*^9}, {3.751119089143136*^9, 3.7511191072746506`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
     0.3]], LineBox[CompressedData["
1:eJwUl3c8lu8Xx0kpQkUlUilSNu0kJyFJKpSMbEURUlkhRLKyyiY7e88Hz3n2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      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
     0.3]], LineBox[CompressedData["
1:eJw1m3c0l//7xxXaGlaI7NKgRanUlUqEQmYohBCFioyy9x7J3ltk73HhzXve
NDQIoaKElNFW3/tzzu/nH+dx7vfxvu/X67qu1/Nxzk38iuMF6+VsbGy32dnY
/vs9MIPd0pkEsP3fT9A/GXUJkhVjAxzOHFOCMC7rV5tJ9rr58s/JY5rwIsf1
+gqSfVNWzs3I6oPOH4t1nzMI6HcXO65wzBSGV8nW9JLMm+/04kiBBajbjVgV
kXw84Wj7S1lrMHHy2+pJcmRRiP/1WlvolhAfO/Pf9WanU3+VHEDmEL10Lcny
YuulQrocYT1/kC8jnQAl+zYpzgJn+DhwzcyHZHOzmakOu1uwRivkzF6SXT7m
/nSXdYH8+a8HB9II6JaZH9n91RW6vrfs9SS50n9m7+saN+g3fH6iJJWA8T8H
TCSU7sJ8hK7hIZLlBUqNWv7dg56+5DutKQQU39u+WoviDRrT8y9qkglIdGNY
y+X7wpSUGu82kgOT3/hMBfnB4WPvTWOSCNj4qFwwz9YfaHeDubQTCTiYwvq4
YncgvE8ccsl/QMCvC0qVFVxBYODBNzmfQIDDUM0W/dkgUBMZ++J5n4CzUpt/
R1SFAL8FR7hiLAHbX1u+rVKMgA8WMVoGMeT65/Y07hKKhDylULHr0QS8YRO8
m/47Esb2FHwMjCTXc3Fk/FpbNKjf3y1gFUqAN3N/YV92LBznqT6jHkKuR4R/
mxN3HPRSUv13BBPgLzHpuNo/Dgj/Rzv6Agjo2WR0QNYqHkSy5uX6vEkeoh87
ui0Blv9I7vf1IuABvWVb1YME6PnHHr/jHgEZmx71Sq58ALNfbx218iDA6gjv
528fHoBIuqFV0G0Cvrxbff1icRJslDCy9bIhIF2M3/f7zjR47bN4JsmagNNs
13s98tJgvF95RYklAYP7XT8tiqTDl5OiO2rNCCj6nMfetzEDJEsWN1wzJODC
e7HPUt8yIfbZ3OR5FQJevCnJCxjJhsvNr4Q+nCRgaLEv48+WHOh8Z3jwzgkC
kr8vXnM0yoGLm77t8T5KwG3lpQMqT3PAiL9dWW4fAWnNF/PLO3Mhbufj4NVb
yPsN9J12yssHO+EtzWICBNxPfvU5cjQftG8cH9/DR0BYknJ5nnAB2PZdEz+4
gYB99+Kl8X4BfMh303m7nICZU1YrCwIKIZBjxKjpIwuubknK3G1ZDNPB6e2O
j1jAcbc4LF+oDLg37JVglrCgnM2Sd0anDMqCPNNFClnwWEf7vGxoGRzeNfm+
PJMFg6cepiZ+L4Ou7v1PfWNYEOWwbgv380dg59yyOOjEAlHeZXoMlQpgvTPy
cNrNAoFxPdF9vyphIbvg1+x2FrA4d2Rf4KsCqfnztbaSLLi3IiLLcW8VKJop
vFERYoGpyMKf1KtVoKFyZWv5ShbMRJ50bH1WBcUHV18+PsYEnuP6+iIl1bBv
ZsbcKJoJ25X3nJTQr4VjuZmXhMOY8I74aCjuWAtTEgNLAwFMuE65ob4ltBbC
h2ZlT3owwTXgZ+m/llqwWWHkRLVigvjv5U2hUnWwetf1rExFJpQ87A1On6uD
FX7EhoxBBmwJK3+RFNYA1oUb1yW/YEBVYWjkh9wGyPgg9iryMQO2qrtc2tva
APxJN0esKAw4XnNatmK2AT6waGP0Egb8kr7+zkavEST7PH7auTHgVcInyyrh
JqjskZLasoEBmY4efaFFzRCm4+CCKxngWHWwWZLSDFq2t+tN2RjQV+3cWzvc
DH9NRfj9vtLB8bzDxU7uFijkzHVz66PDcrZde+/ebQH3Xp9yvgd0ED/56ZLD
+VYYbO48IM5Ph5PVMsJrp9sg80kA8YGLDmP0x0JpnAhY75VWyEmHGWrKRSlR
hJ2sa1PcizTgW/bUQ+gCwmxQV1BSHw2GJBr90uoRBgzaqBbRNIhKPF3jdqId
zr8vt11aRoPa4x6hBis6wNAqyTnsJxXofw80Nm/qgA/O5S82faXCtcR79cIi
HYBerfUbRqkgxh7P++xABxQxFkTorVSwS6AsX2PRAe6qezRl3ajwUCD6ZGlT
B9R3mJ3s/9gN6MgvUXitEybsWX01I92QUdvU4+PSCVW22ZwRL7vB2C30i75P
J+yoidTd2dUNcYXLY+cSOmFbXdOrbZndsK91+/xCeydcfqLuI67XDQHcGz9v
4afA11nLSNmmLgjdPhcy2kIB69QO/5jyLtj3z4r5j0aBXiktv5m8LpAvfWkg
2EeBjT+V8xKiuyB/9uOpo5MU2Nk98jTDqgsik4P4jvB1weKSSUQiVxcMy6x+
JubQBQlzucmKJhRQVXj+7i5fNwhZfyx6q0WByteKziOi3SC/rk86+DQFTnpd
nTi6sxv8Z+tdUJYC5+/tuPv2eDdssHvPmPnXCVst1iyfsOmGOlnxnadzO+FE
3NRbSkM3BJoIac2OdwDs2FxL1aeCl+LlfOnXHaCjtvPxATMqWGpQOAx7O2Cz
aXpFii0VfjzgnS6p64Ckt3tQ35MKw2cFGzcHdwCbFHT6ZFFB74jWgVXbO0Cu
I1C0aJIKvdyjkqaW7aC0XjZ65x0amBL/eH8ZtMP90OsFLG8ayIx88ohXbwc7
2x75qyE0+OE7W9Wwrx245EzKgpNpcNNEzC7lH8LvBUmWZzMNEuTNuE8dRAj6
x/tw218aPI74LSqW3grP99d/cvWiwzLpk53sga3waaOhT0sgHZ51cZ0YdWiF
hk0c2/9E0EE3Km7cX6kVln/zy7JLpcOORNW7roMtkHdIl2epng5CzulLXAIt
oCY358rxhQ6+7FpP90Q0QYj2NrdQEwbYCjfqH7nVBCfm4sa5rjBgYpB+67hx
E3h/bZWLsGVAwNKqhAMyTSBUu/K8qwsDRgrK+Z5RGsH2GvM+WzQDlKQqLcZ/
NsD5VQufptoZ4G4vzx5jUQ/LTb+p8ogx4WgAhf2RSj0UhXiNamxjAv23kXX3
jnrYpe+56t5uJtyINLEf/VoHif/o/+jknHlgHWxB960D0boJ45U6TFg52Tl3
NasW5mfqTgn7MOFTdsFH/oFqkNmoqpfaT15XvBzt1FINsW+mU94OM0H+YGFS
V2Y1VK8hlCTeMSFiMXre5Go1bEqCiLAZJvC2BpWrzVeBt3Lt3n/LWMAMc7YX
X1cF827PNO/sYIHfkw9pq49UwA7bqt3JN1nw/lvWcOXWCnhkO8We5cqCj2US
ogbsFaC8+H5tlgcLVh874y2dXA7c7ZIl4X4soHFE2DW1PoJaSReOTXEskCg4
T3fnLAOCKmLSV86CbcF8FO3eUvh2YD3LoZoFFF7rZLHEUtAee2j6r44Fbdqm
Gx7KlMKNDOuxDW0s+F4PWQ4aDyEwyMnoDYv8/nM8Ro+ii+G93XXYO8GCDRGH
3AWNiqHFJtvSZJIFNobZOl5ixSCqIZnmPc0Cj8TrZgqVRXBgYOFM9RwL7oQb
OBs/KwSNEfsbtL8s+CbTHBTBUwASWfJmOeS5yepb/iB5MB8En8fcuEyeq4+p
g4ezc/Ph6/O4IB7y3D3T0e2adYC8HvW6x1aMgAA7C3Vz3TxYGhUsxJ1kLksX
C/gamwNdBNd3keMEmK1+TGEY54C2eXjnZfKcv5D0ODddMgdGj2Q9SyJzgGvn
ZXfF2mwglt9s+3GGAOcOnqmj/VnwwhnqbLQImDUpSZ/LyoKUxMXEmzoEcLoP
Xcy3y4I42NfkqktATsN91b+LmbCu5Xzbf7mjyYLjzZqjGXBvNW/DMjKXGO5R
xaNEOtjmDMW8NCcgJJ0Isr6UDvpj3gV5VwjYrHNmf553GkTczQzafZWAacbY
myeUFDiRlb5+yoGAPJ8T1X/VE2F9Ws24hDt5f+sCLzEHH8CO1E2m4WSOGq80
SYhxeACGW3asnvEkwKC9azNXVAK4iCmuSCNz2Cjv3DnGk3hoNOPwL/In4Lr+
Tg0Hi3jYomhU8JrMcf36oiVr5uLgeMHXJc4gAvRfXPt+mCcOPkUPqKmRObDD
8mudtX4MhFrxn/GMIOB9+dsLPaxoELGQ4rhD5shtJ47n0aajIPbhtQX7KAJk
OtLNC+QioVWn4ZoymUODW78ohGtFAP9jrS/iZE4tMzumaecUDo+GofA3yfI1
tzZyV4XCJYZJUUo8AXfON8oMPwuBbZ1Sc2Zkzu07XWGQMx8Mxf4+DlvJHPx1
1p2+RSEInjorzQWROfliX7XrE/1AqKg9s7SXzNHvDa5v8HENgL4vhxSfkzyr
evTFk3o/aDBQOLaCzOFXPPCqS7cvtBowB7JIlv+x4g9vnw8ovXNzOkDmeCW6
aJVZhzdwDW9e1kbyFZtq/4ihe3DQ2if8BJn7pQ8zFyq+e8LK4cgNzSTbLbeN
7OH2AL4JkUhZ0husbC/of1VzBa7bqrd/kTz7reL+T8vb8ONe4bAe6R28vE1b
/njdhCOSm08Uksy5yvPmz2QnsFf1Tv1KctVWzpP/9VbBetbsAdJr+O07Lvdk
2oHv8AelGyS3mp7TKH9hDeIXu/2ySPa93LM5fO0V2G+j38EkWXT74yKKnyks
yEb8mCb5CF+whN1nPTjMay6zkvSwI9TtHptq1MGug6EtSPK8moRlHP8hCBTp
cpYkuXjJIYt7Whi362iG/+d5vN5rX2pST2Jwt0W6KMmZwyOrQ79r4y2pFUWb
SO4JVZ6YCDdCA6NjD3+T33dRaXp260ZzVIjgKhwmuX7bzimV15ZYvMs7tZ7k
XcnVejZ5Njj+Ni0klOQnipbCfjfs8WHGrRu6JPsE8+1PUHREjQjuc3wk2yQ+
79TydcYcwXCpx+T65Bd4s2tfvYUbF78s/Od1g2NLz9Q1XNCVy7htJ8nL208W
w947uCfujQ9Brv9G61N/ZfnccdV8ktJVksXp387y/fLAw6P5X7+T+5c1oM+x
+OYumqtLZfmSXFJskk9QvPDmFQU1dpKpVL9n5/R8sCn5z+Rdsh525Ra3Vpzx
RVp2ZuBnsn62b53vttnljwm7tjxsJL1u1yFhk2aRALyro67AQ3Krfp7G6o2B
aBCzvMmKrMcnd2fl4heCcMOV59WzZD1/NsuNNmwNw/1x4zfy4wgg2KdjXMvD
0e+3Ql8b2R+euX97IrMjMG/dywNPyH7SKx6eyg2MQjYZnqnXZL/NLFDyqrfF
4sRui8MxYeR6XV17OSszFrcu+xdsR3qdxqpq6RCBOLT5fPLFEbKfudXdjdTW
xKPBb+7r3YEExMfFPAieuY96H0tSPXwIMOJ+Vyh/OQG9t7bs2E16He/obt+h
3gR0i1rT+ZL0OIZfkohwxQNyvx9xbybnjcTyxt+GN5NQwir12GkXAjQvFKj3
v03Cwxd4t7fdIj3QJS7wgm4yft+aILLvJvk8gkE68vIpyJg8cGC5IwFyUquV
SxZTsdxkeq2OLQHG0ptmv1mn4aNbGbbx5DxM8PEqU3qZhtKPol/0WpH7nz84
U1WXjt/Np8b2WpBeK3DynuqdTNRzXP00+yIBA5KfnO56ZqPhvMfNQ2fJ+X6c
GLGqzsYipdw1a1UJiBr+8lttKht1jrU1vTpN1ruZLSeHSQ622y5YmZLng8lK
4ZFTR3JRcPrVF+5DBPw5l9Px5nseGlvW2ShIEvC8sUtCwrEI2YLGDuh9Y4GK
jYj36odFaCtCcVszzwIuJ3na5EQRljbqNjTMssD2/PsX9y8XY26z7q4l0vM8
VB6tiz9XgtH0tX+kB1mwbnjZW7GdpWjdx9rxo5UFb7mmv0RZl2LOr7kYuSYW
7JQtGljIKkUVPSH2S+T5zNtot1C4uQylV/euyyE9Mb/M7GYxxyN8tHXVCyKD
PE/XBFStGS7HA1T5IwX3WNCjJ3vg+9oK9Hv5euCSOwvmaw7etNpRgTxMoUQu
Fxacvz+8tNeqAo32X3bUd2BBl6GpWexABVbe2dkUZMyCU/HZn20olUjv+jXg
pMACjeU38vfFV+OyEpcOh3EmPLMw43cvr8YrK7n0T40yYUAxkK+ZVY2y1CZ3
7kEmhD/fnSnHUYMf4gXvpjxhwuVGV86+2zWonJgUqdPMBMOcK1pr9GsxPGBx
zyXSGy25hRv+bKzHR0c/w+I+JrwafDQZtLseF/p+j4/uYoLFB9eqNWr1KJLN
rtUtzQTK30NTf73qMbew28lNkAlnF19LJU/X4/TUsEQIGxMmeL0Fo6gNqC9w
jHq+hwEXvnI5q7g0YRFfZlKgBQN8sqP6t0c1YZ6FUhAnmUdrLFuG2AubUDzb
1thbjwExggq5Rf1N2OhX12KuyoB9r8N98442Y3+IS8Lr3QywcXDVNmdrwbRL
DX8ffqMDL6ffl7aAVixo3HPwKZmX10wpuDLSWvG5u6pwLJmnu5brDhE1rVi9
55uIxh06yJmV729734r9YYKeZbZkPvbNvKp+ug3fxff27NKgw2bJsAn25Ygv
fqpYbdxAB5Mz0W2TR9vxo98twaA4GnDs4IpxVmvHAumXSyOhNLBatti9oNeO
89ychw/40mBe6LX2zPV2zLiW2trtSIPBLTI+BZnt2JM6dDpVkwavfqTtP7i8
A01f2Hqu4aRBK9/f1CpKB6ZI1NqsdabCK0tzxazHJEtqrk2woULKWQ9myGAH
5vG8MBS4TAX1SJNO9fkOrM71/LZWgwrbN/flxEp04sLr+oRCKSocCD53VMan
E3+a57dVkV7Yb3Gi1eIQBT8W3du9+2A3iOZJhH9QpuDhhDy2zN3d8HFHYbKt
JgUNJ26lrZPshoibSjdMLSh42+yefP+Gbng7ZVa2JpyC0QKZMvsmu+CtQKmK
9zAF96ywVZxO6QIt0wty9V5daCQXN5f4iwLFKuKSWSFdKDHfddX2CwXYH6xY
FRDXha2P7385MEEBvhm9JKWCLsw6JKLV8pQCGVJrop16uvDQ7iivuCIKLGs4
0zgm1I3NqqxRA30KvPZwsumv7MaQ8Ueo87AT3q9ZTBpt7sbF3WeW52Z2ggnl
u/fb7m60/vli9HN8JxSceHelb6Ab11Zf93a92wk/GcW77JZRsTOpKVvlXCco
DtafvaJFRdEEdJ+Y6YA2b1fROxNUDGJraVPf1QEZ5t3BFbNUfJlzXu7b1g6w
2Omu+e4HFVtK9hencXfAxI9ro/JraTjwWunx65/tYPjD8mPwHhpu2ck6IUxv
h4sB1+SmXGm4bv/fsTrSG9mN7Qvvs9GxKFPyPEMOYWvIqayeVXQUPWaZbseH
4Cdp/f7fRjq2UO1OLPvTBnuazVW0xekIx3dk8DPaYNvuwp1ZynQM7Aj2fn2l
De7e5Yr45UPHjF/KQj33SS8889w47Bcdf2qzy8XMNcOw2f5bH5cxcO7W3IhM
fzO8/GcUC6sZuP3Nyp7G1mZwTHjysn8zA62EZFy7QprBOC/8XL08A8PL1Pru
bW2GifKqHRLXGdhRbagYrNYEcTEX2HL6GTj7g4tvR2IDpGZ1TJa9YaDWsceb
yu41wLoNnOHV7xmY9kVYeJdVA6zcvm/24RcGmldL3+Tb1wDP6iL4dFYxUUCz
9mkusx7eqBMp9geZuE6+9mnpnzpoHtkx9CqSiZVrKDWpprXw0CxtlUA8E8vc
tb2un6yFEz94OnSSmMilr7H1iEwtrC9je1qZwyT7cekXZb4GalIfnpWqZ+JI
BnUgJawG/Gs1w56+YWJoZGCXcX015OkM/T69g4UcW6vPanNVAefL8kweORau
sYx6rfqlEpSNTH1f72dh5r8YzSN9lfDpbO8PbSUWPu86vLghuRJ+N92KGz3P
QrdvRcreUpWwx+6veuhNFvr+Ft7oQnpjXmK67KArC+OVa5K3ilTAFTetw9Ke
LOzzSOIJ/lcOx/pW0rL9WThgt8rrX2g5NH/fkKJ0n4UTV9c+Dch4BC6v2QV+
VLPw0MDy7V+6S8E9l7nEqmfhqWXTn+rDSmEuV+hXYjMLrTx2hN7RKoXJjuX7
BSgsDClVT3rT/xDENXf4Nj5lYeVp1cFzUyWgWTpd6zXDwrZPvgSuL4ao+66N
60QJXOcSHGmrnQ+M25sfVYoTqPJT3e+sQD4sLq/P0ZIisE1K85D0aB4E814M
dd1BYFDfpGCPYx78EjA54nSAwJWja86ORuXCj6GsHO4zJP+sjhIjssG7t19T
VY3AJ13X+Wvis2FbnMvMbXUCJXnuHT9lkg1iGjUbms+Tn49nFup9yoJLncGM
OQMC7biybVVWZQHPjE7OhqsEWtZJjr8ISoPwkzkufTYE/gu7KufFlwYNT+4d
irEjcOxMpYdoXirwlYoELjgQ+HzHochzHSnQ7aGnZHuLQIt3WhXGv5Pg8ZUz
bvO3Cex5vVGmNzQJzJ28M++4EvhDqC7gqEASFNueeXTNncDZvMZLHAqJcMdz
BeW3F4FOOzULdG4kQPxHdq3zPgQGjrBME//ch6u7XCjJ5FLe9rz++lXYfTBa
b2+1JYDAFau00s4WxoP4zvVejBACPfwv6c6PxMJj1kqVd6EEuivUmnDfiIW2
d9xzi2EEDicgl+yfGIh8eW6JM5LAKzbqo/oCMWBvpfmUzJk4mrOy6ktWBCj9
uGFbFktgyKn+QbuOcGh56bbTP47AVc8uXxkaCwPxlDtyQvcJTJyxM3kkEQqi
MmudBkluMh9VXH8qBHh0KYMJCeTW3/6iZmsZDII9X/Z+e0CgzfsnL9fmBYL4
wCahtESSlTNQvysApP482n00icCD0v8qUt77w6slao9VMrm+n/z8+aX9IPfR
L5NZkredK318TsUXHgkJ89xKIZ9PxPWXj7UPrKU9/G2dSuB5nxUB9Rr3oGR2
ZPcLkjkXiuNXRnjC/rzIoGNpBLKX09bpEO4wP5u6KpPkd0dvGt9f5wZSvvNV
P0m+ldn64ammK3wu8go8l05g2nEUXRN5G2xMdvikkNzbFXn9WM9NyN0zljNK
svkaZSUHLmeoMEuYEc0g62Xh3Yxs6g1Iox80NyJ5cPH2prtb7OHOp/pfpPfg
j5xrjZRUG7j0cV1rDcmCPH+aOYWtwDlkV2E/yVH1FrMn08zh7YG1jYskK2iX
6P5QNIav3/Lm1mYSaD8i7m91WBc++czrbiH5uLXygaRbarBXan6I9DiMHHZf
T/koD/IvsyNJj8NNb6nbWg2E8d6ef9ZiJHumrP+xIUwZc+3XXeUlOVj6luDp
UC3UsSMil5EssXOtkWKXAZ4uOTX8gfz+ovGAfQzKJdTUddOjkex908i12OIK
quy+OZ9Jcs+9yM92Y9a4JetIkzPJvhEyu6Qt7LC7ZahIieRvz7/qvx51QOUD
1sj23/P5XNQ8vdcJEwzfLrWS69ddmRq1+Ysz0sWsrG6T/IenIGii/BaOyvyZ
kyS54ZQ5o8LRBYdKW4tJr8OWpaoplz138IwGd8xqknmBJTH7yAMd1j/HdHK/
G2i2Fjk37uJAhrDALpJXbdTqOy/nhc1ulSf3kfXyMtTkGf2lD474HuYrIevJ
eHJ9YnydL6a8wo3CJB+maogaP/BD2oS2/xRZnydoOnkD+gH4xyXvlxrJPCF8
B+MUAvHoUnBqJlnPvwSMalX4gtArLcdYkaz3a+9MCtKeB6PE2d/PNpP9EiVT
78ahG45J4pVDu8h+6rX13xCkEoFvKlYMHSL7TVPoSOW/Q5HYPJ3fciiKnD80
e47XwtH4wZjK9Yrs31/OXY2bbsXinzhPooTs7+T12Yty07GodVrB3zWYwH3r
BLapWseh2zWe14vkPCjY4ztkYxiPd+uCDt33JjDls+r41aMJmPPSpH07OV/W
ti2uNapJQMnhnaer75LzcbGV/5TsAzx/1PR4FTmP3Nvvaq8QTUSnyU2rtcl5
Jn9+f9qx5cnoedPUbK01gXxcjS91aGl4p+Zdz1ZL8u8vCmk9hXSsfcUGOy3I
zycthKs1pGNp1P5dOy6R13c6s0SKM9Bc4dpRmh6BN2WuvNyjkoUa1kqdAScJ
3L3BpCxWOgc3ivNnC5wg8L1nanqwRQ5KmFtE5B0j5+O/GxZu6Tl4omtTeJ4i
gcpf9MTU+XLx/USLkooced1rc24pRx4G7ircvEaAwDdDNsvM3ubjUG3mUR0+
Ai99dOD/J1iA3/ts7sVyk/NsLrk9WacApe8IXVpaR86Lvx/T29oLMOe2Tpbf
MgIXCjb968ooRJ3wnhenJln4dO8rl4aLxRi2VX2XyAQLo1eN3v0dU4xsh2VK
Zt+ysCivEBTpxbhMXWa7zxALOR00OzMOlmBWjJO81mMWbvOWV97K8xC9flrq
FpDnaxCNXX+QWYqCzwSzuCtYuEW2ubN6WRnSFZwk3UpZWHJOhzdQsQyDm0Oe
yuWzUDDKVJa7oAyLUyPeqz9gYVKTND73eYSKm51qjt9h4bot95/fEapAhsh3
6hZ5FmbI5KRGsyrRre5yns4eFjKkWivbPlZie8eqR947WbhQzcr8yFmFR+5X
a3SJsTA0Q+7t7hNVaD7d82p2HQvnTc/xudZUYWh6h8vTd0xMDed4z55WjTfL
Lusywpm4GJA2++xqLba6D9xfGcRE0aS4YU3/Whyq0jtw3IeJS4FDye2ZtRhT
8yPy/m0mSmwrNk3or0XD0e2T46ZMnCAObps/W4fTg/31wruZ+DOmotBtVz1u
YLsn96GLgbnj2c03JxvQT8OlT7eNgc2Fz1MTOBoxPj9et7GegWaTDWGVoo14
5G/S9I0SBq618HF9rt+IAsZxtQHRDOzbNlbd3dGIFzkE1UyNGFjKt/GoVlIT
bn0nvER/T8enMrpRTGjBOy0DjXrDdHyS8+0Vm3ELjlbvjhl4QcfMqDun9txu
weLu97G9VDpKCXBY3i5qwZHpg1JXi+i4OtPyZ8bGVlwRft3s3DU6puy6esBx
pBWlG9Ls107SMPwR7wuGK2JPiFfFuTEaypiek1SJQswo89oXNkBDqxHlvoZ8
xMO5xrNfGTRki29SDn2OuIehG323hIbGbfbDEwLtaF9tu9bnGg3tfucIOrm0
I11jdcI50g/ivG9u89vVgZoH1wkNDlNxVv6ad/vBDtyv80TQ8gUV71Z6V/xS
7sBVq1ixV7qoeNBZNuaKUQcK3xZJF82h4r7Uzz//BXSgv6T0XLwpFdX+7hNx
HO5AXgX2K7d7ulE8/8SadeGdSPRsGI6mdKPEnIVT4YNO7J07sjO/sRvPfrwR
fSynEwMZ+8605nejd5vU1MXGTlw2Md6Xe68bn02ebL3woRMf1x+jau7uRn8/
43nlkxQcuxVjJhHYhW/penvZFih4i/1mzT2PLnzqNOo8/ZeCXftHFfscu/AE
1/oVfau7UGad75CDcRcahs8KRot24avfK94b7+nCeIHQ5E71LvRW5c6V6qfg
vmMmGrxZXZjXfbQsQJqCyW/Urp07040GxBvtGSEKvj/EIJ5odeOenttHdDZS
cCTNY/L8xW607fs1ueZ3JwbNrlM76tCNGu2HOM486cSPPd5Gz2O7Uasj6M6w
eyfu63JCzqFufMX5TjqP0YHGH8Yr9R2o+HdAqMajrQOjF9Q+7HKh4pZVnm80
qztQYkkt6s89Ku4t7+Z+n9aBYuK2MpHRVFx58bDqG8cOPPLUVtu+iorHj9G1
Ofg6UDVmb5Tgdyome18q3GnajoIMGbY9d2noeF1Aqla7HS3olebbAmhYd5KG
R1XacebWux0CETT8KjJ1+ZhcO3Z+rf78KZWGqPkxhJutHT0EPbjONdPwUtmB
D1xnEAPG/f8t+0nDCccYSUOiFZdFFvwWd6JjZ5tctFdNKy4WOry9coeOdfSu
TxlprSgav+JHuhcdR4WiQpgOrbiJ9bJoeSQdmwNmlnrWteKdn8JfA4vp2KW8
+kmYRguKdtzMuTlGx5tSf204upqwm27JPqDJwK8XBYaOFDehfqvq7k+6ZF8G
ew3YRTVhtT/H8QVjBrofU4yqNGrCvjgZ3nlbBtKObK76ON2IdZ7X9FIDGPjl
95T3H55G1JcddbnfxEC1kgXvWdN6tKg2lxMWZ+LeX6pPVJTrca1GE+3MdiaG
GC7LSJCuR2eZjvXXZJlocKH4ifjnOtx18mdGymEmEuvOOsx41aFN752kXB0m
uvneOm9EzqlojkR3XXJudd20LagerMZNjw0qRPuZyM8dc2pvRzVmDt85zD7M
xEubzm4sKqjGSbayg6NjTDx66dyFUOdqFPZLDAmaYqLe9XlZnpXVqNiTYxfw
l4n5vPxzZ/dVYbOrl+hpSRbylmQaO/tVYAgHTwHLhoVN39uCzG0qsOrlQsCg
PTn3xz2rNTQrsId3S+17RxaGVyrs4OevwO3aqpzvyDkvn2l+78eFcix0/H02
OpiF3SbSTdKZZRhYyRObT54TorEf3u7dX4JOAQK9neQ55PraPjvkWzGOJT1f
cWKU9MoExy/9TcVYKPbkVO078n60DAMsTxVjdnMsNfgT6YVWzCsSekWYn8P7
nPjOwls//vzUv12Aex+oH3u5kUAOpiz9uGIBai7tUOvjIZDrudZh8T/5eDba
X43OT57ra1XP9vnnY4f26W0pwuR1Vb/ln+PycEzq1fHh7WROiXg+v64iBxnm
D/ePKpG5/+nYiqRbOagWlixvCgQefSD1VORQDmZxh4k+USZwZjr+iWBbNjIh
vyyT9DxG6HXzF6wsXBgpSRzWInMfy5FbMToLW9P9egUuELh/ymzFgwtZqLby
30cNMmdoSS2bD67KxNqtltRkIwIfYvJEH5GOk+dpm56bExhd7XlQRzcd1QRz
9XqvkLn2j6EYdSANJwOMXdutSI+SOn4ucSIVT32R1IuwJf+eys/Xr/8l4yZT
wWudjgTKNsqocu57gEK/vkUVkjkq8dyKAjFMwOLzoUMryJw18LDmwcFzCTjX
WLnO7L8cVn4u84LdfUx4coPnF+lxkzxw7Xx2HIrb5Va+DiLwcoDNbeU9cbjf
8d2aZWTO2xLNt7CnNRZXtBw9LUbmwOrQ+e5//TEYvk7A4Gw46R0H+HMHxaJQ
0GrzrEo06QV3jTS8lSLx/sp85QNkrqS2ZRVsMYrA03+P3xQkc+dOT2tjiA5D
7fZqhydkLh13+y5FKwnF8zNiB7PjCXxm3BSkRg3Bkb04dI30uILHGxYUl4Iw
0YjW/pHMtTw1Xc5FAkHIGHm6lEbmXhX22Wvc8oGIlPOb1clcvGrDj+qX1/yx
wX/hTRTpcQsSHK77gvywXIWI2Ebm6jcHRhODs33RbO9t/nqSNaRG285VeKP2
ZH5LJ5nLN03WfB6duIePxqb7j5G5va+TvdBB5C5uNPR6UknyeplVxl91PVBA
71juVjL3b9L+5+4Y5oa8pet1AkhWEpBx/9Duiit/9w+8JfnheCfj4vfbWJ0f
cOwI6RFfgza9ocrewoSB355hJJ8VNJTZY+WM3yJ2JvSRTAyWK2xTcMRPXn9D
+EhP2f+qSmsi2x51DtkYapP8e/SUf+Z6W5xYYcAW8J8H3fhac8HTCg+tbPOv
IPmRmwaD7aM5VgjdH3tBcr8X9ax+sTEmT/cKLpA8JPjAKMdPF4W/Xt39n8cR
bEYbX9Sr4RlrA8H/PO5MS1tQ23N5XKGVPPqfx7X5221hCIjC3nuyfv953Ono
ltiYvSfhXjD3X1GS1b5kNC0DbYjqPavHQ7JJ2RORemtDeO/5MuAf+X0W6ZrF
VyMuw5Rva/R7krvKvp0NHrgCU6mcLp0k69Sqhr10uAo85+vlk0nme7Jqnxjb
Nbg+PtRrSzKjt+SiZfx1eHfH79Q+kq24n0RrxTvBwfe1cXPkenVFyWlNmt4E
tmdBLaUk86wudfPadhuKKld0mJG89IwjZf0XF7BvUctaS7L1qhO/RfzdYZmU
3ew5cn+Cl+yi8k55QkQ03W+C3N/KH3oPpDjuwcB2NUU3kn2eTpUEn/SBQRue
NcFkfTw+wJvaIuELg3NJ2zhIpp01uDGz3A+knausPch6CpCZmlCm+IOh3HbN
C2T97bmSI2adGwBrvRnz1WR9btdQuurvHwhxE5Ft60lmp84cqzgVDI5KIm3l
ZH0vDF091k0Jgxwu3muZZH8s8GgsNOWGw8ZE9z1Msn88jo2uKvGPgDsRDoKf
yf5a3yh2+9apKBAoe2wiTvbf4T2KjQZjMaTHN2YpkP0pXSO5RV4nFrIflcXs
CPvPS5fpc3XEwqEp9kJ+sp/9Y+XHq7LiQFVpVHWI7H8vsVUhNLP7YGL83YLP
j8D2Zt4mn8f34XRPdMQzHwLH+q7PyEMCbD9CHwkh58nKffTpyK0PwGGH4bIx
cv5Ix9aZ/RtKhJ7Lfw7DHfJ5e+rLIjWT4JRkUlW3C4GqcqXb+FuSYGnQw0Dl
NtkvKiZyfKnJkPY0WHyvM+ltkFFIN0qFuu3HH1dfI+fDvV9m0vRUeH49oJTd
jkBdMfXrnofSwCdGvEHThsAI7rEtPPzpYHJ3pSmT9MBXWQLDM88yIJTN8e0t
U7K/P19kpUlnw+nLN8/7aJL9owX5HRbZEJm/UVJBnfTq3pAHY+nZ0P/s7q8x
VQJr+i57cvPnAKe9RY3kKfL+MjhvHVyRCyfzNWxUD5PrrRR7xm08DxQbQmw3
SpH7z+6Qd0Y8H8qrm1tVxElPlqpes+FSPtgvaojf2krgBwO2ssjn+aBN1PHX
kV5ovFXT6QSlALz67j8dIr3PV3aPwvXMIuARpqg8mmeh2df2A89fF8FBW6Nx
qy8sDMtzlZXnL4b0ZIFsnhkWfv1z7PGbiGJgHhl0ukh64LDv8e9D7iUgzrkv
IqifhTyLHw/duFAKD+QKom2aWdi8Zf2E41I5lCqp7NT0ZKGll3TiD8EKcN2Y
Y6xDnue7nmqpKChUQNgKC4bWLRaW6v7Jy7GvANmtP6wVyTywEHGxTrO/Ar5d
CK9vMGbhe4Pks/0VlVBh05DtqsjCqfePSzMuV4PmlD3v7GcmVm+XeKjrXg0/
3ccEt35iYrKJ2Aj7/WqQ+nrb58w4E5MOj/ToM6phaKbJxX+QiS8WR9bjgRrQ
CfSXeERjouzf8qvZK2sh9vSlJFoGE3U1j8/ceVgHedzl73nUmKhZSnlbQ6uD
S0/E/X8oMzH6WNmpqXd1MPKZCH9xlIkbQ/i2nxauh9n68bdue5jYf9ovJj+i
HlT6z7224mei2q3rL0UdGkDiq19Q31sGHs3tH2qUbgJqdM4aQVcGnhmaTOFV
boLuCZ/Q9Y4MXKXpQrExbQK19wHlf2wY6Hnkmvz3uCb4u2/Xz86LDDSY0W1s
/NcEy9TzW74rMXB7bNNN6qtm2JY43M++nIHtQl2KdN9WIFqeudUG0fHG2Q8a
Bamt8HfdAaFJMt9uufNA7G5tKyStCprkI/Ov4a/nX9dPtkLdfIuQiQ0dhY/8
vPZEqw3Y1D9w3Fel45+sVreWLQigIvWpYwUdd27cRfE3aAf3jQc+ifjQ0INm
wvHxSjvA0d8Fnndo2GQSUqvq2A4qEhsGn92goZbZeuOfwe3gPNledf0SDe9D
gYZ0Yzt06Chb6R+hYdVhjudpQh1w5e3Zxc9zVDxLM345N9ABU3orjU3NqDiX
WT4w/74D1hklysYYULFFWjD4y2wH7Dqfkth2jorPDQJfDHF2wsqLQYfWKlHR
7rjnN599nRDEKfLOUoCKoz/Ffy0Ed8Lqk029vE+6cXnBNpb7PgrQuv5eDTja
jS8anZc+HaXA9nFCZcP+buTPbAgyPEOByDfTyxJkuvFkp9h9CRMKsK3V3RLL
141cOz/p+gRQINH7Ao/mbBcu18k4ZPSSAkLbfos9zu7C6XNS521du0C7dOSw
EHsX+jq9qOfx7QIHhX7fXT8oyBt3Ur0xvAv+FUcIHpqhYOCLvcNzWV0AjgWn
j72i4E72wauirC7Y6mY5xvmQguOOr66ZbO2GhncuP8J0KDhUqpei3t4Nz4KD
13qmdCJXwZKJArMbDvPnugxFdSKtK+uj4PNu+PLl6gNF/0709Y01fPKhG666
7l49Zt+JES15x+bWU0FXaHzjvFInGsLDlpWmVOjTz0rc+qYDLx585HL1KxWs
7cpPPRTuQOr2k9c//aTCsse3A49s6kDnM44Vtstp4DFhE9bN2YEDgts36fHQ
YL/g4cnez+0ovsZk2YQ8DTpKHdXL29vRDeZYC640YB56KVJs2Y5bD5r3ln+j
gZRMR8HOc4haxdPH3f/SINLytqSKAuL4kHmT0go6OFgHjRqKIJZJajIr+eiQ
/SX8wNWZNiyMjhPQk6eDVuH0u22RbXjW9T31jhMdKl3qS46xWrFhbZi73Hs6
fBiJ2Tyl3IJG7Q5G3FN00GmQV36wowV7lsRVvnylg1Pwvaojm1ow8MEd5ZR/
dJC9BP6Oo81Y46KaVCDEAN4rBT6hXs24ddMng0wtBrROnVgd0NiES1pbt6+o
ZUC2XuT9lp2NKH9au1ymmQExf0Z50jY1orNJGY9KBwMeLX+R6PKjAfcd5bO3
72HAB7bsbn5qA+6dltx9Y5wB0d92WXBbNCB1rW6DOi8TqgdbR+YT6jHH/7KW
wXUmUFjvvcN+1+LP6egB6VtMePoszyJgpBaDMgYXZ9yYsMPgwVY3Si1+WTr9
xiaACXq0uLPnwmtxse6a8vJUJvyunj9RLlSLlh+OfHlMZQK4T+cYKdbg1gwN
oy4BFhwfeLHo5liFfz2WZHJFWPD2vGV264UqVLKfMPGQYMHfEqvtSwpVSL8y
+3bTbhbcPc79zuFPJbJVXtAeP84Ck+G43xtCK3FOk9tf2JIFV0ZiGfbZFTj2
5Fg0JZ8FZ3vLqdbpZVjUIuFnV8wCIenybZVXy1DJX6RyVRkLJuSG9Rf3lKHC
URbur2GBUcUFQ9vOUvyklROs0MkCS2Ls0q+Jh5ihH8K+OMSCUmLj4ddyJaj3
SVRHbpQFPzU2vWz4XoyKyrY95u9YULDzsGBsezHW75g+XznJgsvNizS5C8W4
sFLFnO0bCx7mH1QWcylCh8FXfAZcBAy/MXH70FiAcVnnFsQ3EtDg+Lznql8B
7hhrXJzgJsCq8Ff2qHoBLpvouGwqQEDcTM4fymA+doYtr1+QICBn4ct39aU8
7LM3+/r6IAGnZLfNWkMuPufNqVQ8TEBy8+vo+JW5mJvTGxZ9lADbkS2hLY9z
0PJ0eqDMCQLYH403s5nnoIGYa+TKswTECp7M1vXJxlXZvTfcLxJwsn6Gdtkn
E+12TaVlmxCwWsQ4WZo9E/lHA7d1XCLg3aXd398GZuCa3uyzExYEmI42fFEO
T8efHr9b6XYE6O9buzohIRUDCr3qHtoTIKC0y55XIBWvJqRxBl0nQHO3dXh4
SgoaitvlizkT0Ou8P9MiMxkzXm4ZmrlDgKPWutOVRYnI4XzYI9ydAD5DCnVu
ZyLe1K+/JuZJwOKlycOyZQ9w5NfHE3u9CKA1vAqLrExAn9fqtR/8CbDYvWI1
W1M89lp5D0AgARJGn09wKcXjPKe/ZnQQAd/1pNJ42+KQ/ZSFCG8oAcJL6wy4
O2Nx9do5s9pIAuwEr/OnxUejthTnF1oUAXunWOIWiVE4V/KP9TSagC0Vtq+F
UyPxdKTdVVYsAeW/JoLcc8LR7ulxqeY4Agqa7/NuKQjDFXq03Tn/vWdZL+Bf
UxyKCfyDwgYJ5H7UGR58UhGM+h5j7JIPCBDtnOPVrQlCPatY+Q8kf/8kuepx
fSAeVl12U/+/99ruiZlXt/nj42wdr38kH3w8dFm40w+lzjj0/fde5fU3Gwu8
u33xx9XjhowUAhoLHvo7JHmjTGBqoHYqAQPiLHPezHsYvXf9n16S+4ReHKzO
90S3N45Np9MIMCp8nHm21B0dS9PaK/97r9KRotBfdQe1zW+t508nwPpec5xZ
owuet32R60yyw/pu7VG8hWyDBT5dJI9az642oTqj9Z3evPUZBEQcTqzISnbE
2TyFjaTHwbK3/Q99C+wx/Ba9M4Rk1b3EYeNqG8xOdWlpIPmBVFrUrnZLFPeS
Wxoh2X58qmUm2Qx9pT4E/CV58cSmZo9qQ6SeeKDLm0nWSxk327IULfSTVbAT
J/nU7eEnnCmA////colLRplacdEt/wOO+PXH
      "]]}}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{-0.2233679039340025, 0.2233609925674475}, {-0.2233596160606619,
    0.2233721931981476}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.75111858246358*^9, 3.751118656674474*^9}, {
  3.751119034091157*^9, 3.75111904948765*^9}, {3.751119095694533*^9, 
  3.751119107598105*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xfromZ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"xBack0", "//.", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"d10imsol", ",", "w0sub", ",", "d3sol"}], "}"}], "]"}]}], "/.",
       "vals"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Z0", "\[Rule]", 
       RowBox[{
        RowBox[{"Zre", "[", "t", "]"}], "+", 
        RowBox[{"I", " ", 
         RowBox[{"Zim", "[", "t", "]"}]}]}]}], ",", 
      RowBox[{"Z0bar", "\[Rule]", 
       RowBox[{
        RowBox[{"Zre", "[", "t", "]"}], "-", 
        RowBox[{"I", " ", 
         RowBox[{"Zim", "[", "t", "]"}]}]}]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yfromZ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"yBack0", "//.", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"d10imsol", ",", "w0sub", ",", "d3sol"}], "}"}], "]"}]}], "/.",
       "vals"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Z0", "\[Rule]", 
       RowBox[{
        RowBox[{"Zre", "[", "t", "]"}], "+", 
        RowBox[{"I", " ", 
         RowBox[{"Zim", "[", "t", "]"}]}]}]}], ",", 
      RowBox[{"Z0bar", "\[Rule]", 
       RowBox[{
        RowBox[{"Zre", "[", "t", "]"}], "-", 
        RowBox[{"I", " ", 
         RowBox[{"Zim", "[", "t", "]"}]}]}]}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.751044302575354*^9, 3.751044309817583*^9}, {
  3.751044355742713*^9, 3.7510444308780627`*^9}, {3.7510445953775787`*^9, 
  3.7510446008978453`*^9}, {3.7510475753293858`*^9, 3.7510475889950676`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xfromZlist", "=", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"xfromZ", "/.", "Zsol"}], "//", "Evaluate"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "tmax", ",", "0.1"}], "}"}]}], "]"}], 
     "]"}], "//", "Re"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yfromZlist", "=", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"yfromZ", "/.", "Zsol"}], "//", "Evaluate"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "tmax", ",", "0.1"}], "}"}]}], "]"}], 
     "]"}], "//", "Re"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.751041847695326*^9, 3.7510418555438824`*^9}, {
  3.7510418939922953`*^9, 3.7510419086276865`*^9}, {3.751041957614102*^9, 
  3.7510420330883045`*^9}, {3.7510477894664927`*^9, 3.7510478313497467`*^9}, {
  3.751047875412792*^9, 3.751047885817375*^9}, {3.751048010521652*^9, 
  3.751048022214226*^9}, {3.7510480776293755`*^9, 3.7510480788931074`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "redo", " ", "numerical", " ", "example", " ", "from", " ", "above"}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"xsim", "=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"LHS", "\[Equal]", "0"}], "/.", "vals"}], ",", 
         RowBox[{
          RowBox[{"x", "[", "0", "]"}], "\[Equal]", "x0"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], 
       ",", 
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xlist", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], "/.", "xsim"}], "//", "Evaluate"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "tmax", ",", "0.1"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dxlist", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], "/.", "xsim"}], ",", "t"}], "]"}], "//",
          "Evaluate"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "tmax", ",", "0.1"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plotxdx", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"xlist", ",", "dxlist"}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.751041847695326*^9, 3.7510418555438824`*^9}, {
  3.7510418939922953`*^9, 3.7510419086276865`*^9}, {3.751041957614102*^9, 
  3.7510420330883045`*^9}, {3.751048348703477*^9, 3.751048424102026*^9}, {
  3.751118326479453*^9, 3.751118327898755*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotxfromZ", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"xfromZlist", ",", "yfromZlist"}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"plotxdx", ",", "plotxfromZ"}], "]"}]}], "Input",
 CellChangeTimes->{{3.751042059280138*^9, 3.7510421006556015`*^9}, {
  3.751044066367116*^9, 3.751044087243449*^9}, {3.751047841934003*^9, 
  3.7510478561046977`*^9}, {3.7510479091571436`*^9, 3.751047980002026*^9}, {
  3.751048044329686*^9, 3.751048088761337*^9}, {3.7511184481293206`*^9, 
  3.7511184525337267`*^9}, {3.7511191140580983`*^9, 3.751119116642464*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwdmnk8VP/3xyVKJYnQIlukKCmfUMrJWlIpVIpQhBCRJakkEpE9O8mWfV/G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       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJwVl3c01f8fx0WREVmJokIiMhsUXlHRVEoZZaZCWsqoZI8iO5S99977dfcW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       "]]}}, {}, {}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.22348586173227963`, 0.2235668405928862}, {-0.2247614613444, 
   0.22483483539311008`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.751047980550272*^9, {3.7510480124843235`*^9, 3.7510480892056627`*^9}, 
   3.751048283046541*^9, {3.7510483986013975`*^9, 3.7510484265887985`*^9}, {
   3.7510484770772715`*^9, 3.751048493373499*^9}, 3.7510485576423883`*^9, 
   3.7511183397657094`*^9, {3.7511184142020397`*^9, 3.751118448895811*^9}, 
   3.751118831086714*^9, 3.751119059210815*^9, 3.751119117279625*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1536, 781},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
Magnification->1.25,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 162, 2, 91, "Chapter"],
Cell[CellGroupData[{
Cell[767, 28, 105, 1, 83, "Subchapter"],
Cell[875, 31, 1315, 32, 79, "Input"],
Cell[CellGroupData[{
Cell[2215, 67, 3282, 87, 258, "Input"],
Cell[5500, 156, 53131, 887, 298, "Output"]
}, Open  ]],
Cell[58646, 1046, 954, 28, 62, "Input"],
Cell[CellGroupData[{
Cell[59625, 1078, 547, 14, 37, "Input"],
Cell[60175, 1094, 22738, 385, 308, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[82962, 1485, 116, 1, 83, "Subchapter"],
Cell[CellGroupData[{
Cell[83103, 1490, 117, 1, 59, "Subsection"],
Cell[83223, 1493, 233, 6, 37, "Input"],
Cell[83459, 1501, 1858, 47, 79, "Input"],
Cell[85320, 1550, 574, 13, 62, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85931, 1568, 109, 1, 59, "Subsection"],
Cell[86043, 1571, 935, 25, 62, "Input"],
Cell[86981, 1598, 1026, 28, 62, "Input"],
Cell[88010, 1628, 1403, 37, 64, "Input"],
Cell[89416, 1667, 902, 25, 62, "Input"],
Cell[CellGroupData[{
Cell[90343, 1696, 947, 27, 62, "Input"],
Cell[91293, 1725, 294, 4, 37, "Output"]
}, Open  ]],
Cell[91602, 1732, 1213, 34, 79, "Input"],
Cell[92818, 1768, 976, 27, 62, "Input"],
Cell[93797, 1797, 1451, 37, 64, "Input"],
Cell[95251, 1836, 1220, 34, 79, "Input"],
Cell[CellGroupData[{
Cell[96496, 1874, 1053, 29, 62, "Input"],
Cell[97552, 1905, 366, 5, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97967, 1916, 241, 7, 63, "Subsection"],
Cell[98211, 1925, 1071, 31, 62, "Input"],
Cell[99285, 1958, 1187, 30, 78, "Input"],
Cell[100475, 1990, 557, 14, 62, "Input"],
Cell[101035, 2006, 865, 20, 62, "Input"],
Cell[101903, 2028, 800, 23, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102740, 2056, 1012, 31, 99, "Subsection"],
Cell[CellGroupData[{
Cell[103777, 2091, 706, 16, 62, "Input"],
Cell[104486, 2109, 2296, 53, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106819, 2167, 952, 22, 62, "Input"],
Cell[107774, 2191, 1168, 22, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108979, 2218, 513, 11, 37, "Input"],
Cell[109495, 2231, 1248, 29, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[110780, 2265, 323, 6, 37, "Input"],
Cell[111106, 2273, 1641, 44, 116, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112784, 2322, 763, 20, 64, "Input"],
Cell[113550, 2344, 568, 8, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114155, 2357, 367, 7, 37, "Input"],
Cell[114525, 2366, 458, 6, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115020, 2377, 350, 9, 40, "Input"],
Cell[115373, 2388, 466, 6, 37, "Output"]
}, Open  ]],
Cell[115854, 2397, 851, 21, 64, "Input"],
Cell[116708, 2420, 464, 13, 40, "Input"],
Cell[117175, 2435, 353, 10, 40, "Input"],
Cell[117531, 2447, 2364, 49, 110, "Input"],
Cell[CellGroupData[{
Cell[119920, 2500, 941, 24, 86, "Input"],
Cell[120864, 2526, 1754, 33, 62, "Output"]
}, Open  ]],
Cell[122633, 2562, 914, 22, 64, "Input"],
Cell[CellGroupData[{
Cell[123572, 2588, 410, 9, 37, "Input"],
Cell[123985, 2599, 2783, 76, 116, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[126817, 2681, 107, 1, 59, "Subsection"],
Cell[CellGroupData[{
Cell[126949, 2686, 670, 17, 62, "Input"],
Cell[127622, 2705, 417, 7, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128076, 2717, 624, 14, 62, "Input"],
Cell[128703, 2733, 1249, 30, 67, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129989, 2768, 330, 9, 62, "Input"],
Cell[130322, 2779, 333, 6, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130692, 2790, 650, 16, 62, "Input"],
Cell[131345, 2808, 514, 10, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131896, 2823, 627, 16, 62, "Input"],
Cell[132526, 2841, 368, 6, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[132955, 2854, 108, 1, 83, "Subchapter"],
Cell[133066, 2857, 674, 13, 37, "Input"],
Cell[133743, 2872, 237, 6, 37, "Input"],
Cell[CellGroupData[{
Cell[134005, 2882, 398, 11, 62, "Input"],
Cell[134406, 2895, 566, 8, 37, "Output"],
Cell[134975, 2905, 563, 9, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[135575, 2919, 621, 17, 62, "Input"],
Cell[136199, 2938, 468, 7, 37, "Output"]
}, Open  ]],
Cell[136682, 2948, 1145, 34, 37, "Input"],
Cell[137830, 2984, 359, 11, 62, "Input"],
Cell[138192, 2997, 844, 22, 37, "Input"],
Cell[CellGroupData[{
Cell[139061, 3023, 1245, 34, 86, "Input"],
Cell[140309, 3059, 80590, 1333, 468, "Output"]
}, Open  ]],
Cell[220914, 4395, 1622, 48, 62, "Input"],
Cell[222539, 4445, 1097, 27, 62, "Input"],
Cell[223639, 4474, 2153, 62, 134, "Input"],
Cell[CellGroupData[{
Cell[225817, 4540, 810, 17, 62, "Input"],
Cell[226630, 4559, 43433, 724, 297, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

